@@ -11,6 +11,7 @@ import subprocess
 import sys
 from abc import ABC, abstractmethod
 from argparse import RawDescriptionHelpFormatter
+from datetime import datetime
 from pathlib import Path
 from typing import Any
 
@@ -142,7 +143,7 @@ class BaseCommand(ABC):
         self,
         console: Console,
         tools: ToolCache = None,
-        apps: dict = None,
+        apps: dict[str, AppConfig] = None,
         base_path: Path = None,
         data_path: Path = None,
         is_clone: bool = False,
@@ -170,6 +171,7 @@ class BaseCommand(ABC):
             console=console,
             base_path=self.data_path / "tools",
         )
+        self.validate_python_version()
 
         # Immediately add tools that must be always available
         Subprocess.verify(tools=self.tools)
@@ -287,6 +289,36 @@ a custom location for Briefcase's tools.
 """
             )
 
+    def validate_python_version(self) -> bool:
+        """Validate the system's Python version is within its end-of-life date.
+
+        :return: True if the Python version is within its end-of-life date.
+        """
+        # Python EOL dates are provided on: https://devguide.python.org/versions/
+        # EOL for Python 3.8 was October 2024. Assuming Python releases occur on the
+        # same yearly cadence, the EOL for Python 3.x is October of 2024 + (x - 8)
+        EOL_year = 2024 + (sys.version_info.minor - 8)
+        if datetime.today() > datetime(EOL_year, 10, 1):
+            self.console.warning(
+                f"""
+*************************************************************************
+** WARNING: Your Python version is unsupported!                        **
+*************************************************************************
+
+    The version of Python you are using ({platform.python_version()}) is past its
+    end of life. As a result, it is highly likely your Briefcase
+    version is also out of date.
+
+    See https://devguide.python.org/versions/ for details on currently
+    supported Python versions.
+
+*************************************************************************
+"""
+            )
+            return False
+
+        return True
+
     def _command_factory(self, command_name: str):
         """Command factory for the current platform and format.
 
@@ -401,9 +433,63 @@ a custom location for Briefcase's tools.
 
         :param app: The app config
         """
-        return self.binary_executable_path(app).parent / (
-            "Stub" + self.binary_executable_path(app).suffix
-        )
+
+        if sys.platform == "win32":  # pragma: no-cover-if-not-windows
+            suffix = self.binary_executable_path(app).suffix
+        else:  # pragma: no-cover-if-is-windows
+            suffix = ""
+
+        return self.binary_executable_path(app).parent / f"Stub{suffix}"
+
+    def bundle_package_path(self, app):
+        """The root path of the content in the bundle generated by Briefcase that will
+        be packaged for distribution.
+
+        This may be overridden if the user manually specifies external_package_path.
+
+        :param app: The app config
+        """
+        # We raise NotImplementedError(), rather than making the method an
+        # abstractmethod so that we don't have to define this method on platforms that
+        # don't support external packaging. If this method is ever invoked on a platform
+        # that doesn't support external packaging, we've got a problem.
+        raise NotImplementedError()
+
+    def package_path(self, app):
+        """The root path of the content that will be packaged for distribution.
+
+        :param app: The app config
+        """
+        if app.external_package_path:
+            return Path(app.external_package_path).absolute().resolve()
+        else:
+            return self.bundle_package_path(app)
+
+    def bundle_package_executable_path(self, app):
+        """The path, relative to the package path generated by Briefcase, of the binary
+        in the packaged app that is executed as the app.
+
+        This may be overridden if the user manually specifies a
+        external_package_executable_path.
+
+        :param app: The app config
+        """
+        # We raise NotImplementedError(), rather than making the method an
+        # abstractmethod so that we don't have to define this method on platforms that
+        # don't support external packaging. If this method is ever invoked on a platform
+        # that doesn't support external packaging, we've got a problem.
+        raise NotImplementedError()
+
+    def package_executable_path(self, app):
+        """The path, relative to the package path, of the binary that is executed as the
+        app.
+
+        :param app: The app config
+        """
+        if app.external_package_executable_path:
+            return app.external_package_executable_path
+        else:
+            return self.bundle_package_executable_path(app)
 
     def briefcase_toml(self, app: AppConfig) -> dict[str, ...]:
         """Load the ``briefcase.toml`` file provided by the app template.
@@ -579,6 +665,7 @@ a custom location for Briefcase's tools.
 
         Raises MissingToolException if a required system tool is missing.
         """
+        return
 
     def finalize_app_config(self, app: AppConfig):
         """Finalize the application config.
@@ -594,8 +681,9 @@ a custom location for Briefcase's tools.
 
         :param app: The app configuration to finalize.
         """
+        return
 
-    def finalize(self, app: AppConfig | None = None):
+    def finalize(self, app: AppConfig | None = None, test_mode: bool = False):
         """Finalize Briefcase configuration.
 
         This will:
@@ -612,16 +700,34 @@ a custom location for Briefcase's tools.
         self.verify_host()
         self.verify_tools()
 
-        if app is None:
-            for app in self.apps.values():
-                if hasattr(app, "__draft__"):
-                    self.finalize_app_config(app)
-                    delattr(app, "__draft__")
-        else:
+        apps = self.apps.values() if app is None else [app]
+        for app in apps:
             if hasattr(app, "__draft__"):
+                app.test_mode = test_mode
                 self.finalize_app_config(app)
                 delattr(app, "__draft__")
 
+                if app.external_package_path:
+                    # Package path is defined
+                    if app.sources is not None:
+                        # sources is not defined
+                        raise BriefcaseConfigError(
+                            f"{app.app_name!r} is declared as an external app, but also "
+                            "defines 'sources'. External apps (apps defining 'external_package_path') "
+                            "cannot define sources."
+                        )
+                elif app.sources is None:
+                    # Neither sources or package_path is defined
+                    raise BriefcaseConfigError(
+                        f"{app.app_name!r} does not define either 'sources' or 'external_package_path'."
+                    )
+                else:
+                    # sources is defined, package_path is not
+                    if app.external_package_executable_path:
+                        raise BriefcaseConfigError(
+                            f"{app.app_name!r} defines 'external_package_executable_path', but not 'external_package_path'."
+                        )
+
     def verify_app(self, app: AppConfig):
         """Verify the app is compatible and the app tools are available.
 
@@ -637,6 +743,7 @@ a custom location for Briefcase's tools.
 
     def verify_app_tools(self, app: AppConfig):
         """Verify that tools needed to run the command for this app exist."""
+        return
 
     def verify_app_template(self, app: AppConfig):
         """Verify the template targets the same Briefcase version as the Command.
@@ -670,7 +777,8 @@ any compatibility problems, and then add the compatibility declaration.
             )
 
     def verify_required_python(self, app: AppConfig):
-        """Verify that the running version of Python meets the project's specifications."""
+        """Verify that the running version of Python meets the project's
+        specifications."""
 
         requires_python = getattr(self.global_config, "requires_python", None)
         if not requires_python:
@@ -771,6 +879,7 @@ any compatibility problems, and then add the compatibility declaration.
 
         :param command: The command whose options are to be cloned
         """
+        return
 
     def add_default_options(self, parser):
         """Add the default options that exist on *all* commands.
@@ -883,6 +992,7 @@ any compatibility problems, and then add the compatibility declaration.
 
         :param parser: a stub argparse parser for the command.
         """
+        return
 
     def parse_config(self, filename, overrides):
         try:
@@ -1156,3 +1266,23 @@ Did you run Briefcase in a project directory that contains {filename.name!r}?"""
                 output_path=output_path,
                 extra_context=extra_context,
             )
+
+    def get_git_config_value(self, section: str, option: str) -> str | None:
+        """Get the requested git config value, if available.
+
+        :param section: The configuration section.
+        :param option: The configuration option.
+        :returns: The configuration value, or None.
+        """
+        git_config_paths = [
+            self.tools.git.config.get_config_path("system"),
+            self.tools.git.config.get_config_path("global"),
+            self.tools.git.config.get_config_path("user"),
+            ".git/config",
+        ]
+
+        with self.tools.git.config.GitConfigParser(git_config_paths) as git_config:
+            if git_config.has_option(section, option):
+                return git_config.get_value(section, option)
+
+        return None
