@@ -146,6 +146,50 @@ def validate_document_type_config(document_type_id, document_type):
             f"The URL associated with document type {document_type_id!r} is invalid: {e}"
         )
 
+    if sys.platform == "darwin":  # pragma: no-cover-if-not-macos
+        from briefcase.platforms.macOS.utils import is_uti_core_type, mime_type_to_uti
+
+        macOS = document_type.setdefault("macOS", {})
+        content_types = macOS.get("LSItemContentTypes", None)
+        mime_type = document_type.get("mime_type", None)
+
+        if isinstance(content_types, list):
+            if len(content_types) > 1:
+                raise BriefcaseConfigError(
+                    f"""
+Document type {document_type_id!r} has multiple content types. Specifying
+multiple values in a LSItemContentTypes key is only valid when multiple document
+types are manually grouped together in the Info.plist file. For Briefcase apps,
+document types are always separately declared in the configuration file, so only
+a single value should be provided.
+                """
+                )
+
+            macOS["LSItemContentTypes"] = content_types
+            uti = content_types[0]
+        elif isinstance(content_types, str):
+            # If the content type is a string, convert it to a list
+            macOS["LSItemContentTypes"] = [content_types]
+            uti = content_types
+        else:
+            uti = None
+
+        # If an UTI is provided in LSItemContentTypes, that takes precedence over a MIME type
+        if is_uti_core_type(uti) or ((uti := mime_type_to_uti(mime_type)) is not None):
+            macOS.setdefault("is_core_type", True)
+            macOS.setdefault("LSItemContentTypes", [uti])
+            macOS.setdefault("LSHandlerRank", "Alternate")
+        else:
+            # LSItemContentTypes will default to bundle.app_name.document_type_id
+            # in the Info.plist template if it is not provided.
+            macOS.setdefault("is_core_type", False)
+            macOS.setdefault("LSHandlerRank", "Owner")
+            macOS.setdefault("UTTypeConformsTo", ["public.data", "public.content"])
+
+        macOS.setdefault("CFBundleTypeRole", "Viewer")
+    else:  # pragma: no-cover-if-is-macos
+        pass
+
 
 VALID_BUNDLE_RE = re.compile(r"[a-zA-Z0-9-]+(\.[a-zA-Z0-9-]+)+$")
 
@@ -201,11 +245,58 @@ def parsed_version(version):
     return SimpleNamespace(**groupdict)
 
 
+def parse_boolean(value: str) -> bool:
+    """Takes a string value and attempts to convert to a boolean value."""
+
+    truth_vals = {"true", "t", "yes", "y", "1", "on"}
+    false_vals = {"false", "f", "no", "n", "0", "off"}
+
+    normalised_val = value.strip().lower()
+
+    if normalised_val in truth_vals:
+        return True
+    elif normalised_val in false_vals:
+        return False
+    else:
+        raise ValueError(
+            f"Invalid boolean value: {value!r}. Expected one of {truth_vals | false_vals}"
+        )
+
+
 class BaseConfig:
     def __init__(self, **kwargs):
         for attr, value in kwargs.items():
             setattr(self, attr, value)
 
+    def update(self, data):
+        """Add fields and values from data to BaseConfig instance.
+
+        Any existing fields named in data will be overwritten. To merge
+        data with existing configs, use the `merge_config` function.
+
+        :param data: The new configuration data dictionary.
+        """
+        for key, configs in data.items():
+            setattr(self, key, configs)
+
+    def copy(self):
+        return type(self)(**self.__dict__)
+
+    def setdefault(self, field_name, default_value):
+        """Return the field_name field or, if it does not exist, create it to hold
+        default_value.
+
+        Behaves similarly to dict.setdefault().
+
+        :param field_name: The name of the desired/new field.
+        :param default_value: The value to assign to self.field_name if it does not
+            already exist.
+        """
+        if not hasattr(self, field_name):
+            setattr(self, field_name, default_value)
+
+        return getattr(self, field_name)
+
 
 class GlobalConfig(BaseConfig):
     def __init__(
@@ -249,8 +340,8 @@ class AppConfig(BaseConfig):
         version,
         bundle,
         description,
-        sources,
         license,
+        sources=None,
         formal_name=None,
         url=None,
         author=None,
@@ -267,6 +358,8 @@ class AppConfig(BaseConfig):
         long_description=None,
         console_app=False,
         requirement_installer_args: list[str] | None = None,
+        external_package_path: str | None = None,
+        external_package_executable_path: str | None = None,
         **kwargs,
     ):
         super().__init__(**kwargs)
@@ -299,6 +392,10 @@ class AppConfig(BaseConfig):
         self.requirement_installer_args = (
             [] if requirement_installer_args is None else requirement_installer_args
         )
+        self.external_package_path = external_package_path
+        self.external_package_executable_path = external_package_executable_path
+
+        self.test_mode: bool = False
 
         if not is_valid_app_name(self.app_name):
             raise BriefcaseConfigError(
@@ -328,20 +425,21 @@ class AppConfig(BaseConfig):
                 "see https://www.python.org/dev/peps/pep-0440/ for details."
             )
 
-        # Sources list doesn't include any duplicates
-        source_modules = {source.rsplit("/", 1)[-1] for source in self.sources}
-        if len(self.sources) != len(source_modules):
-            raise BriefcaseConfigError(
-                f"The `sources` list for {self.app_name!r} contains duplicated "
-                "package names."
-            )
+        if self.sources:
+            # Sources list doesn't include any duplicates
+            source_modules = {source.rsplit("/", 1)[-1] for source in self.sources}
+            if len(self.sources) != len(source_modules):
+                raise BriefcaseConfigError(
+                    f"The `sources` list for {self.app_name!r} contains duplicated "
+                    "package names."
+                )
 
-        # There is, at least, a source for the app module
-        if self.module_name not in source_modules:
-            raise BriefcaseConfigError(
-                f"The `sources` list for {self.app_name!r} does not include a "
-                f"package named {self.module_name!r}."
-            )
+            # There is, at least, a source for the app module
+            if self.module_name not in source_modules:
+                raise BriefcaseConfigError(
+                    f"The `sources` list for {self.app_name!r} does not include a "
+                    f"package named {self.module_name!r}."
+                )
 
     def __repr__(self):
         return f"<{self.bundle_identifier} v{self.version} AppConfig>"
@@ -387,14 +485,11 @@ class AppConfig(BaseConfig):
         `module_name`."""
         return self.bundle.replace("-", "_")
 
-    def PYTHONPATH(self, test_mode):
-        """The PYTHONPATH modifications needed to run this app.
-
-        :param test_mode: Should test_mode sources be included?
-        """
+    def PYTHONPATH(self):
+        """The PYTHONPATH modifications needed to run this app."""
         paths = []
-        sources = self.sources
-        if test_mode and self.test_sources:
+        sources = self.sources.copy() if self.sources else []
+        if self.test_mode and self.test_sources:
             sources.extend(self.test_sources)
 
         for source in sources:
@@ -403,15 +498,23 @@ class AppConfig(BaseConfig):
                 paths.append(path)
         return paths
 
-    def main_module(self, test_mode: bool):
+    def all_sources(self) -> list[str]:
+        """Get all sources of the application that should be copied to the app.
+
+        :returns: The Path to the dist-info folder.
+        """
+        sources = self.sources.copy() if self.sources else []
+        if self.test_mode and self.test_sources:
+            sources.extend(self.test_sources)
+        return sources
+
+    def main_module(self):
         """The path to the main module for the app.
 
         In normal operation, this is ``app.module_name``; however,
         in test mode, it is prefixed with ``tests.``.
-
-        :param test_mode: Are we running in test mode?
         """
-        if test_mode:
+        if self.test_mode:
             return f"tests.{self.module_name}"
         else:
             return self.module_name
@@ -576,7 +679,7 @@ def parse_config(config_file, platform, output_format, console):
     The current configuration for {section_name} has a 'license' field
     that is specified as a string:
 
-        license = "{config['license']}"
+        license = "{config["license"]}"
 
     To use the PEP 621 format (and to remove this warning), specify that
     the LICENSE file contains the license for {section_name}:
