@@ -9,12 +9,12 @@ import sys
 import textwrap
 import time
 import traceback
-from collections.abc import Iterable, Mapping
+from collections.abc import Callable, Iterable, Mapping
 from contextlib import contextmanager
 from datetime import datetime
 from enum import IntEnum
 from pathlib import Path
-from typing import Any, Callable
+from typing import Any
 
 from rich.console import Console as RichConsole
 from rich.control import strip_control_codes
@@ -30,6 +30,7 @@ from rich.progress import (
 from rich.traceback import Trace, Traceback
 
 from briefcase import __version__
+from briefcase.config import parse_boolean
 from briefcase.exceptions import InputDisabled
 
 # Max width for printing to console; matches argparse's default width
@@ -200,8 +201,13 @@ class Console:
         # dynamic elements like the Wait Bar.
         self.is_console_controlled = False
 
-    def __del__(self):
+    def close(self):
         self._dev_null.close()
+        self._dev_null = None
+
+    def __del__(self):
+        if self._dev_null:
+            self.close()
 
     #################################################################
     # Console primitives
@@ -732,7 +738,7 @@ class Console:
         :returns: True if the user selected "y", or False if they selected "n".
         """
         if default is None:
-            yes_no = "y/n"
+            yes_no = "[y/n]"
             default_text = None
         elif default:
             yes_no = "[Y/n]"
@@ -938,7 +944,7 @@ class Console:
         if isinstance(options, dict):
             ordered = list(options.items())
         else:
-            ordered = list(zip(options, options))
+            ordered = list(zip(options, options, strict=True))
 
         if default is not None:
             try:
@@ -946,7 +952,7 @@ class Console:
             except ValueError:
                 raise ValueError(f"{default!r} is not a valid default value")
 
-        for i, (key, value) in enumerate(ordered, start=1):
+        for i, (_, value) in enumerate(ordered, start=1):
             self.prompt(f"  {i}) {value}")
 
         self.prompt()
@@ -960,3 +966,40 @@ class Console:
         )
 
         return ordered[int(index) - 1][0]
+
+    def boolean_question(
+        self,
+        description,
+        intro: str,
+        default: bool | None = None,
+        override_value: str | None = None,
+    ) -> bool:
+        """Ask the user a boolean question who's answer requires selecting yes/no.
+
+        :param description: A short description of the question being asked. This text
+            is used in prompts and a header bar prefacing the question.
+        :param intro: An introductory paragraph explaining the question being asked.
+        :param default: The default option for empty user input.
+        :param override_value: A pre-selected answer for the question. This can be used
+            to shortcut asking the question, such as when a command line option provides
+            a value. If provided and valid, the header bar will be displayed, but the
+            intro paragraph and option list will not. Will take the provided string and
+            attempt to parse into bool
+        :returns: The user's chosen answer or none if closed without input
+        """
+
+        self.divider(title=description)
+
+        if override_value is not None:
+            self.print()
+            self.print(f"Using override value {override_value!r}")
+            try:
+                return parse_boolean(override_value)
+            except ValueError as e:
+                raise ValueError(f"Invalid override value for {description}: {e}")
+
+        self.prompt()
+        self.prompt(self.textwrap(intro))
+        self.prompt()
+
+        return self.input_boolean(description, default=default)
