@@ -6,7 +6,7 @@ import socket
 import subprocess
 import sys
 from collections.abc import Iterable, Mapping
-from functools import lru_cache
+from functools import cache
 from pathlib import Path, PosixPath, PurePosixPath
 
 from packaging.version import InvalidVersion, Version
@@ -344,7 +344,11 @@ Delete this file and run Briefcase again.
 
         return is_user_mapped
 
-    @lru_cache(maxsize=None)
+    # B019 is a warning about @cache on methods possibly causing memory leaks,
+    # since the cache retains a reference to the instance that called the
+    # method. Since the Docker tools usually exist one at a time, this is not
+    # a big concern
+    @cache  # noqa B019
     def cache_image(self, image_tag: str):
         """Ensures an image is available and cached locally.
 
