@@ -6,6 +6,8 @@ import time
 from pathlib import Path
 from uuid import UUID
 
+from packaging.version import Version
+
 from briefcase.commands import (
     BuildCommand,
     CreateCommand,
@@ -66,7 +68,9 @@ class iOSXcodePassiveMixin(iOSMixin):
 
         briefcase open iOS
 
-    and use Xcode's app distribution workflow.
+    and use Xcode's app distribution workflow described at:
+
+        https://briefcase.readthedocs.io/en/stable/reference/platforms/iOS/xcode.html#ios-deploy
 
 *************************************************************************
 """
@@ -316,18 +320,69 @@ class iOSXcodeCreateCommand(iOSXcodePassiveMixin, CreateCommand):
         app: AppConfig,
         requires: list[str],
         app_packages_path: Path,
+        **kwargs,
     ):
-        # Determine the min iOS version from the VERSIONS file in the support package.
-        versions = dict(
-            [part.strip() for part in line.split(": ", 1)]
-            for line in (
-                (self.support_path(app) / "VERSIONS")
-                .read_text(encoding="UTF-8")
-                .split("\n")
+        try:
+            # Determine the min iOS version from the framework metadata
+            # of the ios-arm64 slice of the XCframework
+            plist_file = (
+                self.support_path(app)
+                / "Python.xcframework/ios-arm64/Python.framework/Info.plist"
             )
-            if ": " in line
+            with plist_file.open("rb") as f:
+                info_plist = plistlib.load(f)
+
+            support_min_version = info_plist["MinimumOSVersion"]
+        except KeyError:
+            raise BriefcaseCommandError(
+                "Your iOS XCframework doesn't specify a minimum iOS version."
+            )
+        except FileNotFoundError:
+            # If a plist file couldn't be found, it's an old-style support package;
+            # Determine the min iOS version from the VERSIONS file in the support package.
+            versions = dict(
+                [part.strip() for part in line.split(": ", 1)]
+                for line in (
+                    (self.support_path(app) / "VERSIONS")
+                    .read_text(encoding="UTF-8")
+                    .split("\n")
+                )
+                if ": " in line
+            )
+            support_min_version = versions.get("Min iOS version", "13.0")
+
+        # Check that the app's definition is compatible with the support package.
+        # If the app doesn't specify a minimum version, use the support package
+        # minimum version as a default.
+        ios_min_version = getattr(app, "min_os_version", support_min_version)
+
+        if Version(ios_min_version) < Version(support_min_version):
+            raise BriefcaseCommandError(
+                f"Your iOS app specifies a minimum iOS version of {ios_min_version}, "
+                f"but the support package only supports {support_min_version}"
+            )
+
+        ios_min_tag = ios_min_version.replace(".", "_")
+
+        # Feb 2025: The platform-site was moved into the xcframework as
+        # `platform-config`. Look for the new location; fall back to the old location.
+        device_platform_site = (
+            self.support_path(app)
+            / "Python.xcframework/ios-arm64/platform-config/arm64-iphoneos"
         )
-        ios_min_tag = versions.get("Min iOS version", "13.0").replace(".", "_")
+        simulator_platform_site = (
+            self.support_path(app)
+            / "Python.xcframework/ios-arm64_x86_64-simulator"
+            / f"platform-config/{self.tools.host_arch}-iphonesimulator"
+        )
+        if not device_platform_site.exists():
+            device_platform_site = (
+                self.support_path(app) / "platform-site/iphoneos.arm64"
+            )
+            simulator_platform_site = (
+                self.support_path(app)
+                / f"platform-site/iphonesimulator.{self.tools.host_arch}"
+            )
 
         # Perform the initial install pass targeting the "iphoneos" platform
         super()._install_app_requirements(
@@ -340,11 +395,15 @@ class iOSXcodeCreateCommand(iOSXcodePassiveMixin, CreateCommand):
             ],
             pip_kwargs={
                 "env": {
-                    "PYTHONPATH": str(
-                        self.support_path(app) / "platform-site/iphoneos.arm64"
-                    )
+                    "PYTHONPATH": str(device_platform_site),
+                    "PIP_REQUIRE_VIRTUALENV": None,
                 }
             },
+            install_hint=f"""
+
+This may be because the `iphoneos` wheels that are available are not compatible
+with a minimum iOS version of {ios_min_version}.
+""",
         )
 
         # Perform a second install pass targeting the "iphonesimulator" platform for the
@@ -359,13 +418,17 @@ class iOSXcodeCreateCommand(iOSXcodePassiveMixin, CreateCommand):
             ],
             pip_kwargs={
                 "env": {
-                    "PYTHONPATH": str(
-                        self.support_path(app)
-                        / "platform-site"
-                        / f"iphonesimulator.{self.tools.host_arch}"
-                    )
-                }
+                    "PYTHONPATH": str(simulator_platform_site),
+                    "PIP_REQUIRE_VIRTUALENV": None,
+                },
             },
+            install_hint=f"""
+
+This may indicate that an `iphoneos` wheel could be found, but an
+`iphonesimulator` wheel could not be found; or that the `iphonesimulator`
+binary wheels that are available are not compatible with a minimum iOS
+version of {ios_min_version}.
+""",
         )
 
 
@@ -388,7 +451,7 @@ class iOSXcodeBuildCommand(iOSXcodePassiveMixin, BuildCommand):
         """
         return self.bundle_path(app) / self.path_index(app, "info_plist_path")
 
-    def update_app_metadata(self, app: AppConfig, test_mode: bool):
+    def update_app_metadata(self, app: AppConfig):
         with self.console.wait_bar("Setting main module..."):
             # Load the original plist
             with self.info_plist_path(app).open("rb") as f:
@@ -396,20 +459,19 @@ class iOSXcodeBuildCommand(iOSXcodePassiveMixin, BuildCommand):
 
             # Set the name of the app's main module; this will depend
             # on whether we're in test mode.
-            info_plist["MainModule"] = app.main_module(test_mode)
+            info_plist["MainModule"] = app.main_module()
 
             # Write the modified plist
             with self.info_plist_path(app).open("wb") as f:
                 plistlib.dump(info_plist, f)
 
-    def build_app(self, app: AppConfig, test_mode: bool = False, **kwargs):
+    def build_app(self, app: AppConfig, **kwargs):
         """Build the Xcode project for the application.
 
         :param app: The application to build
-        :param test_mode: Should the app be updated in test mode? (default: False)
         """
         self.console.info("Updating app metadata...", prefix=app.app_name)
-        self.update_app_metadata(app=app, test_mode=test_mode)
+        self.update_app_metadata(app=app)
 
         self.console.info("Building Xcode project...", prefix=app.app_name)
         with self.console.wait_bar("Building..."):
@@ -452,15 +514,14 @@ class iOSXcodeRunCommand(iOSXcodeMixin, RunCommand):
     def run_app(
         self,
         app: AppConfig,
-        test_mode: bool,
+        *,
         passthrough: list[str],
         udid=None,
-        **kwargs,
-    ):
+        **options,
+    ) -> dict | None:
         """Start the application.
 
         :param app: The config object for the app
-        :param test_mode: Boolean; Is the app running in test mode?
         :param passthrough: The list of arguments to pass to the app
         :param udid: The device UDID to target. If ``None``, the user will
             be asked to select a device at runtime.
@@ -472,7 +533,7 @@ class iOSXcodeRunCommand(iOSXcodeMixin, RunCommand):
                 "Input has been disabled; can't select a device to target."
             ) from e
 
-        if test_mode:
+        if app.test_mode:
             label = "test suite"
         else:
             label = "app"
@@ -506,7 +567,7 @@ class iOSXcodeRunCommand(iOSXcodeMixin, RunCommand):
                     f"Unable to boot {device} simulator running {iOS_version}"
                 ) from e
 
-        if not test_mode:
+        if not app.test_mode:
             # We now know the simulator is *running*, so we can open it.
             # We don't need to open the simulator to run the test suite.
             try:
@@ -625,7 +686,6 @@ class iOSXcodeRunCommand(iOSXcodeMixin, RunCommand):
             self._stream_app_logs(
                 app,
                 popen=simulator_log_popen,
-                test_mode=test_mode,
                 clean_filter=macOS_log_clean_filter,
                 clean_output=True,
                 stop_func=lambda: is_process_dead(app_pid),
