@@ -6,6 +6,7 @@ import subprocess
 from briefcase.commands import (
     BuildCommand,
     CreateCommand,
+    DevCommand,
     PackageCommand,
     PublishCommand,
     RunCommand,
@@ -36,7 +37,7 @@ class LinuxAppImagePassiveMixin(LinuxMixin):
     supported_host_os_reason = (
         "Linux AppImages can only be built on Linux, or on macOS using Docker."
     )
-    platform_target_version = "0.3.20"
+    platform_target_version: str | None = "0.3.20"
 
     def appdir_path(self, app):
         return self.bundle_path(app) / f"{app.formal_name}.AppDir"
@@ -369,23 +370,21 @@ class LinuxAppImageRunCommand(LinuxAppImagePassiveMixin, RunCommand):
     def run_app(
         self,
         app: AppConfig,
-        test_mode: bool,
         passthrough: list[str],
         **kwargs,
     ):
         """Start the application.
 
         :param app: The config object for the app
-        :param test_mode: Boolean; Is the app running in test mode?
         :param passthrough: The list of arguments to pass to the app
         """
         # Set up the log stream
-        kwargs = self._prepare_app_kwargs(app=app, test_mode=test_mode)
+        kwargs = self._prepare_app_kwargs(app=app)
 
         # Console apps must operate in non-streaming mode so that console input can
         # be handled correctly. However, if we're in test mode, we *must* stream so
         # that we can see the test exit sentinel
-        if app.console_app and not test_mode:
+        if app.console_app and not app.test_mode:
             self.console.info("=" * 75)
             self.tools.subprocess.run(
                 [self.binary_path(app)] + passthrough,
@@ -409,11 +408,14 @@ class LinuxAppImageRunCommand(LinuxAppImagePassiveMixin, RunCommand):
             self._stream_app_logs(
                 app,
                 popen=app_popen,
-                test_mode=test_mode,
                 clean_output=False,
             )
 
 
+class LinuxAppImageDevCommand(LinuxAppImageMixin, DevCommand):
+    description = "Run a Linux AppImage app in development mode"
+
+
 class LinuxAppImagePackageCommand(LinuxAppImageMixin, PackageCommand):
     description = "Package a Linux AppImage."
 
@@ -437,3 +439,4 @@ build = LinuxAppImageBuildCommand
 run = LinuxAppImageRunCommand
 package = LinuxAppImagePackageCommand
 publish = LinuxAppImagePublishCommand
+dev = LinuxAppImageDevCommand
