@@ -52,7 +52,7 @@ def test_no_code(
 
     myapp.sources = None
 
-    create_command.install_app_code(myapp, test_mode=False)
+    create_command.install_app_code(myapp)
 
     # No request was made to install requirements
     create_command.tools.shutil.rmtree.assert_called_once_with(app_path)
@@ -78,7 +78,7 @@ def test_empty_code(
 
     myapp.sources = []
 
-    create_command.install_app_code(myapp, test_mode=False)
+    create_command.install_app_code(myapp)
 
     # No request was made to install requirements
     create_command.tools.shutil.rmtree.assert_called_once_with(app_path)
@@ -101,7 +101,7 @@ def test_source_missing(
     myapp.sources = ["missing"]
 
     with pytest.raises(MissingAppSources):
-        create_command.install_app_code(myapp, test_mode=False)
+        create_command.install_app_code(myapp)
 
     # Distinfo won't be created.
     dist_info_path = app_path / "myapp-1.2.3.dist-info"
@@ -140,7 +140,7 @@ def test_source_dir(
     # Set the app definition, and install sources
     myapp.sources = ["src/first", "src/second"]
 
-    create_command.install_app_code(myapp, test_mode=False)
+    create_command.install_app_code(myapp)
 
     # All the sources exist.
     assert (app_path / "first").exists()
@@ -184,7 +184,7 @@ def test_source_file(
     # Set the app definition, and install sources
     myapp.sources = ["src/demo.py", "other.py"]
 
-    create_command.install_app_code(myapp, test_mode=False)
+    create_command.install_app_code(myapp)
 
     # All the sources exist.
     assert (app_path / "demo.py").exists()
@@ -233,7 +233,7 @@ def test_no_existing_app_folder(
     # Set the app definition, and install sources
     myapp.sources = ["src/first/demo.py", "src/second"]
 
-    create_command.install_app_code(myapp, test_mode=False)
+    create_command.install_app_code(myapp)
 
     # All the new sources exist, and contain the new content.
     assert (app_path / "demo.py").exists()
@@ -336,7 +336,7 @@ def test_replace_sources(
     # Set the app definition, and install sources
     myapp.sources = ["src/first/demo.py", "src/second"]
 
-    create_command.install_app_code(myapp, test_mode=False)
+    create_command.install_app_code(myapp)
 
     # All the new sources exist, and contain the new content.
     assert (app_path / "demo.py").exists()
@@ -387,7 +387,7 @@ def test_non_latin_metadata(
 
     myapp.sources = []
 
-    create_command.install_app_code(myapp, test_mode=False)
+    create_command.install_app_code(myapp)
 
     # No request was made to install requirements
     create_command.tools.shutil.rmtree.assert_called_once_with(app_path)
@@ -474,7 +474,7 @@ def test_test_sources(
     myapp.sources = ["src/first", "src/second"]
     myapp.test_sources = ["tests", "othertests"]
 
-    create_command.install_app_code(myapp, test_mode=False)
+    create_command.install_app_code(myapp)
 
     # App sources exist.
     assert (app_path / "first").exists()
@@ -545,8 +545,9 @@ def test_test_sources_test_mode(
     # Set the app definition, and install sources
     myapp.sources = ["src/first", "src/second"]
     myapp.test_sources = ["tests", "othertests"]
+    myapp.test_mode = True
 
-    create_command.install_app_code(myapp, test_mode=True)
+    create_command.install_app_code(myapp)
 
     # App sources exist.
     assert (app_path / "first").exists()
@@ -616,8 +617,9 @@ def test_only_test_sources_test_mode(
     # Set the app definition, and install sources
     myapp.sources = None
     myapp.test_sources = ["tests", "othertests"]
+    myapp.test_mode = True
 
-    create_command.install_app_code(myapp, test_mode=True)
+    create_command.install_app_code(myapp)
 
     # App sources do not exist.
     assert not (app_path / "first").exists()
