@@ -80,7 +80,7 @@ def test_bad_path_index(create_command, myapp, bundle_path, app_requirements_pat
         BriefcaseCommandError,
         match=r"Application path index file does not define `app_requirements_path` or `app_packages_path`",
     ):
-        create_command.install_app_requirements(myapp, test_mode=False)
+        create_command.install_app_requirements(myapp)
 
     # pip wasn't invoked
     create_command.tools[myapp].app_context.run.assert_not_called()
@@ -102,7 +102,7 @@ def test_app_packages_no_requires(
     """If an app has no requirements, install_app_requirements is a no-op."""
     myapp.requires = None
 
-    create_command.install_app_requirements(myapp, test_mode=False)
+    create_command.install_app_requirements(myapp)
 
     # No request was made to install requirements
     create_command.tools[myapp].app_context.run.assert_not_called()
@@ -117,7 +117,7 @@ def test_app_packages_empty_requires(
     """If an app has an empty requirements list, install_app_requirements is a no-op."""
     myapp.requires = []
 
-    create_command.install_app_requirements(myapp, test_mode=False)
+    create_command.install_app_requirements(myapp)
 
     # No request was made to install requirements
     create_command.tools[myapp].app_context.run.assert_not_called()
@@ -132,7 +132,7 @@ def test_app_packages_valid_requires(
     """If an app has a valid list of requirements, pip is invoked."""
     myapp.requires = ["first", "second==1.2.3", "third>=3.2.1"]
 
-    create_command.install_app_requirements(myapp, test_mode=False)
+    create_command.install_app_requirements(myapp)
 
     # A request was made to install requirements
     create_command.tools[myapp].app_context.run.assert_called_with(
@@ -173,7 +173,7 @@ def test_app_packages_requirement_installer_args_no_paths(
     myapp.requirement_installer_args = ["--no-cache"]
     myapp.requires = ["package"]
 
-    create_command.install_app_requirements(myapp, test_mode=False)
+    create_command.install_app_requirements(myapp)
 
     # A request was made to install requirements
     create_command.tools[myapp].app_context.run.assert_called_with(
@@ -210,7 +210,7 @@ def test_app_packages_requirement_installer_args_path_transformed(
     myapp.requirement_installer_args = ["--extra-index-url", "./packages"]
     myapp.requires = ["package"]
 
-    create_command.install_app_requirements(myapp, test_mode=False)
+    create_command.install_app_requirements(myapp)
 
     # A request was made to install requirements
     create_command.tools[myapp].app_context.run.assert_called_with(
@@ -242,13 +242,13 @@ def test_app_packages_requirement_installer_args_coincidental_path_not_transform
     app_path,
     app_packages_path_index,
 ):
-    """If an app's requirement installer arguments includes a path that exists,
-    but it starts with `-`, it is used as-is."""
+    """If an app's requirement installer arguments includes a path that exists, but it
+    starts with `-`, it is used as-is."""
     (create_command.base_path / "-f" / "wheels").mkdir(parents=True, exist_ok=True)
     myapp.requirement_installer_args = ["-f./wheels"]
     myapp.requires = ["package"]
 
-    create_command.install_app_requirements(myapp, test_mode=False)
+    create_command.install_app_requirements(myapp)
 
     # A request was made to install requirements
     create_command.tools[myapp].app_context.run.assert_called_with(
@@ -279,13 +279,13 @@ def test_app_packages_requirement_installer_args_path_not_transformed(
     app_path,
     app_packages_path_index,
 ):
-    """If an app's requirement installer arguments have an argument that looks like a local path,
-    but does not resolve to an existing path, it is used as-is."""
+    """If an app's requirement installer arguments have an argument that looks like a
+    local path, but does not resolve to an existing path, it is used as-is."""
     (create_command.base_path / "packages").unlink(missing_ok=True)
     myapp.requirement_installer_args = ["--extra-index-url", "./packages"]
     myapp.requires = ["package"]
 
-    create_command.install_app_requirements(myapp, test_mode=False)
+    create_command.install_app_requirements(myapp)
 
     # A request was made to install requirements
     create_command.tools[myapp].app_context.run.assert_called_with(
@@ -317,13 +317,13 @@ def test_app_packages_requirement_installer_args_combined_argument_not_transform
     app_path,
     app_packages_path_index,
 ):
-    """If an app's requirement installer arguments use a combined argument,
-    paths are not modified."""
+    """If an app's requirement installer arguments use a combined argument, paths are
+    not modified."""
     (create_command.base_path / "packages").mkdir(exist_ok=True)
     myapp.requirement_installer_args = ["--extra-index-url=./packages"]
     myapp.requires = ["package"]
 
-    create_command.install_app_requirements(myapp, test_mode=False)
+    create_command.install_app_requirements(myapp)
 
     # A request was made to install requirements
     create_command.tools[myapp].app_context.run.assert_called_with(
@@ -362,7 +362,7 @@ def test_app_packages_valid_requires_no_support_package(
         "paths": {"app_packages_path": "path/to/app_packages"}
     }
 
-    create_command.install_app_requirements(myapp, test_mode=False)
+    create_command.install_app_requirements(myapp)
 
     # A request was made to install requirements
     create_command.tools[myapp].app_context.run.assert_called_with(
@@ -403,14 +403,14 @@ def test_app_packages_invalid_requires(
     # Unfortunately, no way to tell the difference between "offline" and
     # "your requirements are invalid"; pip returns status code 1 for all
     # failures.
-    create_command.tools[myapp].app_context.run.side_effect = (
-        subprocess.CalledProcessError(
-            cmd=["python", "-u", "-m", "pip", "..."], returncode=1
-        )
+    create_command.tools[
+        myapp
+    ].app_context.run.side_effect = subprocess.CalledProcessError(
+        cmd=["python", "-u", "-m", "pip", "..."], returncode=1
     )
 
     with pytest.raises(RequirementsInstallError):
-        create_command.install_app_requirements(myapp, test_mode=False)
+        create_command.install_app_requirements(myapp)
 
     # But the request to install was still made
     create_command.tools[myapp].app_context.run.assert_called_with(
@@ -449,14 +449,14 @@ def test_app_packages_offline(
     # Unfortunately, no way to tell the difference between "offline" and
     # "your requirements are invalid"; pip returns status code 1 for all
     # failures.
-    create_command.tools[myapp].app_context.run.side_effect = (
-        subprocess.CalledProcessError(
-            cmd=["python", "-u", "-m", "pip", "..."], returncode=1
-        )
+    create_command.tools[
+        myapp
+    ].app_context.run.side_effect = subprocess.CalledProcessError(
+        cmd=["python", "-u", "-m", "pip", "..."], returncode=1
     )
 
     with pytest.raises(RequirementsInstallError):
-        create_command.install_app_requirements(myapp, test_mode=False)
+        create_command.install_app_requirements(myapp)
 
     # But the request to install was still made
     create_command.tools[myapp].app_context.run.assert_called_with(
@@ -501,12 +501,14 @@ def test_app_packages_install_requirements(
     myapp.requires = ["first", "second", "third"]
 
     # The side effect of calling pip is creating installation artefacts
-    create_command.tools[myapp].app_context.run.side_effect = (
-        create_installation_artefacts(app_packages_path, myapp.requires)
+    create_command.tools[
+        myapp
+    ].app_context.run.side_effect = create_installation_artefacts(
+        app_packages_path, myapp.requires
     )
 
     # Install the requirements
-    create_command.install_app_requirements(myapp, test_mode=False)
+    create_command.install_app_requirements(myapp)
 
     # The request to install was made
     create_command.tools[myapp].app_context.run.assert_called_with(
@@ -556,12 +558,14 @@ def test_app_packages_replace_existing_requirements(
     myapp.requires = ["first", "second", "third"]
 
     # The side effect of calling pip is creating installation artefacts
-    create_command.tools[myapp].app_context.run.side_effect = (
-        create_installation_artefacts(app_packages_path, myapp.requires)
+    create_command.tools[
+        myapp
+    ].app_context.run.side_effect = create_installation_artefacts(
+        app_packages_path, myapp.requires
     )
 
     # Install the requirements
-    create_command.install_app_requirements(myapp, test_mode=False)
+    create_command.install_app_requirements(myapp)
 
     # The request to install was still made
     create_command.tools[myapp].app_context.run.assert_called_with(
@@ -613,7 +617,7 @@ def test_app_requirements_no_requires(
     myapp.requires = None
 
     # Install requirements into the bundle
-    create_command.install_app_requirements(myapp, test_mode=False)
+    create_command.install_app_requirements(myapp)
 
     # requirements.txt doesn't exist either
     assert app_requirements_path.exists()
@@ -637,7 +641,7 @@ def test_app_requirements_empty_requires(
     myapp.requires = []
 
     # Install requirements into the bundle
-    create_command.install_app_requirements(myapp, test_mode=False)
+    create_command.install_app_requirements(myapp)
 
     # requirements.txt doesn't exist either
     assert app_requirements_path.exists()
@@ -661,7 +665,7 @@ def test_app_requirements_requires(
     myapp.requires = ["first", "second==1.2.3", "third>=3.2.1"]
 
     # Install requirements into the bundle
-    create_command.install_app_requirements(myapp, test_mode=False)
+    create_command.install_app_requirements(myapp)
 
     # requirements.txt doesn't exist either
     assert app_requirements_path.exists()
@@ -681,14 +685,14 @@ def test_app_requirements_requirement_installer_args_no_template_support(
     mock_now,
     app_requirements_path_index,
 ):
-    """If an app has requirement install args, a requirements file is still written,
-    but no requirement installer args file is written if the template does not support it.
-    """
+    """If an app has requirement install args, a requirements file is still written, but
+    no requirement installer args file is written if the template does not support
+    it."""
     myapp.requirement_installer_args = ["--no-cache"]
     myapp.requires = ["my-favourite-package"]
 
     # Install requirements into the bundle
-    create_command.install_app_requirements(myapp, test_mode=False)
+    create_command.install_app_requirements(myapp)
 
     # requirements.txt exists either
     assert app_requirements_path.exists()
@@ -709,13 +713,13 @@ def test_app_requirements_requirement_installer_args_with_template_support(
     mock_now,
     app_requirement_installer_args_path_index,
 ):
-    """If an app has requirement install args, a requirements file is still written,
-    and requirement installer args file is written if the template supports it."""
+    """If an app has requirement install args, a requirements file is still written, and
+    requirement installer args file is written if the template supports it."""
     myapp.requirement_installer_args = ["--no-cache", "-f", "wheels with space"]
     myapp.requires = ["my-favourite-package"]
 
     # Install requirements into the bundle
-    create_command.install_app_requirements(myapp, test_mode=False)
+    create_command.install_app_requirements(myapp)
 
     # requirements.txt exists either
     assert app_requirements_path.exists()
@@ -742,14 +746,14 @@ def test_app_requirements_requirement_installer_args_without_requires_no_templat
     mock_now,
     app_requirements_path_index,
 ):
-    """If an app has requirement install args and no requires,
-    a requirements file is still written with the timestamp,
-    and does not write a requirement installer args file."""
+    """If an app has requirement install args and no requires, a requirements file is
+    still written with the timestamp, and does not write a requirement installer args
+    file."""
     myapp.requirement_installer_args = ["--no-cache"]
     myapp.requires = []
 
     # Install requirements into the bundle
-    create_command.install_app_requirements(myapp, test_mode=False)
+    create_command.install_app_requirements(myapp)
 
     # requirements.txt exists either
     assert app_requirements_path.exists()
@@ -772,14 +776,14 @@ def test_app_requirements_requirement_installer_args_without_requires_with_templ
     mock_now,
     app_requirement_installer_args_path_index,
 ):
-    """If an app has requirement install args and no requires,
-    a requirements file is still written with the timestamp,
-    as well as requirement installer args file when the template supports it."""
+    """If an app has requirement install args and no requires, a requirements file is
+    still written with the timestamp, as well as requirement installer args file when
+    the template supports it."""
     myapp.requirement_installer_args = ["--no-cache", "-f", "wheels with space"]
     myapp.requires = []
 
     # Install requirements into the bundle
-    create_command.install_app_requirements(myapp, test_mode=False)
+    create_command.install_app_requirements(myapp)
 
     # requirements.txt exists either
     assert app_requirements_path.exists()
@@ -833,7 +837,7 @@ def _test_app_requirements_paths(
         converted = requirement
     myapp.requires = ["first", requirement, "third"]
 
-    create_command.install_app_requirements(myapp, test_mode=False)
+    create_command.install_app_requirements(myapp)
     with app_requirements_path.open(encoding="utf-8") as f:
         assert f.read() == (
             "\n".join(
@@ -972,7 +976,7 @@ def test_app_packages_test_requires(
     myapp.requires = ["first", "second==1.2.3", "third>=3.2.1"]
     myapp.test_requires = ["pytest", "pytest-tldr"]
 
-    create_command.install_app_requirements(myapp, test_mode=False)
+    create_command.install_app_requirements(myapp)
 
     # A request was made to install requirements
     create_command.tools[myapp].app_context.run.assert_called_with(
@@ -1010,8 +1014,9 @@ def test_app_packages_test_requires_test_mode(
     """If an app has test requirements and we're in test mode, they are installed."""
     myapp.requires = ["first", "second==1.2.3", "third>=3.2.1"]
     myapp.test_requires = ["pytest", "pytest-tldr"]
+    myapp.test_mode = True
 
-    create_command.install_app_requirements(myapp, test_mode=True)
+    create_command.install_app_requirements(myapp)
 
     # A request was made to install requirements
     create_command.tools[myapp].app_context.run.assert_called_with(
@@ -1052,8 +1057,9 @@ def test_app_packages_only_test_requires_test_mode(
     installed."""
     myapp.requires = None
     myapp.test_requires = ["pytest", "pytest-tldr"]
+    myapp.test_mode = True
 
-    create_command.install_app_requirements(myapp, test_mode=True)
+    create_command.install_app_requirements(myapp)
 
     # A request was made to install requirements
     create_command.tools[myapp].app_context.run.assert_called_with(
