@@ -36,10 +36,9 @@ def test_toga_bootstrap(new_command):
         project_overrides={},
     )
 
-    assert context == dict(
-        app_source='''\
+    assert context == {
+        "app_source": '''\
 import toga
-from toga.style import Pack
 from toga.style.pack import COLUMN, ROW
 
 
@@ -61,13 +60,13 @@ class {{ cookiecutter.class_name }}(toga.App):
 def main():
     return {{ cookiecutter.class_name }}()
 ''',
-        app_start_source="""\
+        "app_start_source": """\
 from {{ cookiecutter.module_name }}.app import main
 
 if __name__ == "__main__":
     main().main_loop()
 """,
-        pyproject_table_briefcase_app_extra_content="""
+        "pyproject_table_briefcase_app_extra_content": """
 requires = [
 ]
 test_requires = [
@@ -76,38 +75,49 @@ test_requires = [
 {% endif %}
 ]
 """,
-        pyproject_table_macOS="""\
+        "pyproject_table_macOS": """\
 universal_build = true
 requires = [
-    "toga-cocoa~=0.4.7",
+    "toga-cocoa~=0.5.0",
     "std-nslog~=1.0.3",
 ]
 """,
-        pyproject_table_linux="""\
+        "pyproject_table_linux": """\
 requires = [
-    "toga-gtk~=0.4.7",
+    "toga-gtk~=0.5.0",
+    # PyGObject 3.52.1 enforces a requirement on libgirepository-2.0-dev. This library
+    # isn't available on Debian 12/Ubuntu 22.04. If you don't need to support those (or
+    # older) releases, you can remove this version pin. See beeware/toga#3143.
+    "pygobject < 3.52.1",
 ]
 """,
-        pyproject_table_linux_system_debian="""\
+        "pyproject_table_linux_system_debian": """\
 system_requires = [
     # Needed to compile pycairo wheel
     "libcairo2-dev",
-    # Needed to compile PyGObject wheel
+    # One of the following two packages are needed to compile PyGObject wheel. If you
+    # remove the pygobject pin in the requires list, you should also change to the
+    # version 2.0 of the girepository library. See beeware/toga#3143.
     "libgirepository1.0-dev",
+    # "libgirepository-2.0-dev",
 ]
 
 system_runtime_requires = [
     # Needed to provide GTK and its GI bindings
     "gir1.2-gtk-3.0",
+    # One of the following two packages are needed to use PyGObject at runtime. If you
+    # remove the pygobject pin in the requires list, you should also change to the
+    # version 2.0 of the girepository library. See beeware/toga#3143.
     "libgirepository-1.0-1",
+    # "libgirepository-2.0-0",
     # Dependencies that GTK looks for at runtime
     "libcanberra-gtk3-module",
     # Needed to provide WebKit2 at runtime
-    # Note: Debian 11 and Ubuntu 20.04 require gir1.2-webkit2-4.0 instead
+    # Note: Debian 11 requires gir1.2-webkit2-4.0 instead
     # "gir1.2-webkit2-4.1",
 ]
 """,
-        pyproject_table_linux_system_rhel="""\
+        "pyproject_table_linux_system_rhel": """\
 system_requires = [
     # Needed to compile pycairo wheel
     "cairo-gobject-devel",
@@ -126,7 +136,7 @@ system_runtime_requires = [
     # "webkit2gtk3",
 ]
 """,
-        pyproject_table_linux_system_suse="""\
+        "pyproject_table_linux_system_suse": """\
 system_requires = [
     # Needed to compile pycairo wheel
     "cairo-devel",
@@ -145,7 +155,7 @@ system_runtime_requires = [
     # "libwebkit2gtk3", "typelib(WebKit2)",
 ]
 """,
-        pyproject_table_linux_system_arch="""\
+        "pyproject_table_linux_system_arch": """\
 system_requires = [
     # Needed to compile pycairo wheel
     "cairo",
@@ -172,7 +182,7 @@ system_runtime_requires = [
     # "webkit2gtk",
 ]
 """,
-        pyproject_table_linux_appimage="""\
+        "pyproject_table_linux_appimage": """\
 manylinux = "manylinux_2_28"
 
 system_requires = [
@@ -193,25 +203,25 @@ linuxdeploy_plugins = [
     "DEPLOY_GTK_VERSION=3 gtk",
 ]
 """,
-        pyproject_table_linux_flatpak="""\
+        "pyproject_table_linux_flatpak": """\
 flatpak_runtime = "org.gnome.Platform"
-flatpak_runtime_version = "47"
+flatpak_runtime_version = "48"
 flatpak_sdk = "org.gnome.Sdk"
 """,
-        pyproject_table_windows="""\
+        "pyproject_table_windows": """\
 requires = [
-    "toga-winforms~=0.4.7",
+    "toga-winforms~=0.5.0",
 ]
 """,
-        pyproject_table_iOS="""\
+        "pyproject_table_iOS": """\
 requires = [
-    "toga-iOS~=0.4.7",
+    "toga-iOS~=0.5.0",
     "std-nslog~=1.0.3",
 ]
 """,
-        pyproject_table_android="""\
+        "pyproject_table_android": """\
 requires = [
-    "toga-android~=0.4.7",
+    "toga-android~=0.5.0",
 ]
 
 base_theme = "Theme.MaterialComponents.Light.DarkActionBar"
@@ -224,13 +234,13 @@ build_gradle_dependencies = [
     # "org.osmdroid:osmdroid-android:6.1.20",
 ]
 """,
-        pyproject_table_web="""\
+        "pyproject_table_web": """\
 requires = [
-    "toga-web~=0.4.7",
+    "toga-web~=0.5.0",
 ]
 style_framework = "Shoelace v2.3"
 """,
-    )
+    }
 
 
 def test_console_bootstrap(new_command):
@@ -247,21 +257,21 @@ def test_console_bootstrap(new_command):
         project_overrides={},
     )
 
-    assert context == dict(
-        console_app=True,
-        app_source="""\
+    assert context == {
+        "console_app": True,
+        "app_source": """\
 
 def main():
     # Your app logic goes here
     print("Hello, World.")
 """,
-        app_start_source="""\
+        "app_start_source": """\
 from {{ cookiecutter.module_name }}.app import main
 
 if __name__ == "__main__":
     main()
 """,
-        pyproject_table_briefcase_app_extra_content="""
+        "pyproject_table_briefcase_app_extra_content": """
 requires = [
     # Add your cross-platform app requirements here
 ]
@@ -271,18 +281,18 @@ test_requires = [
 {% endif %}
 ]
 """,
-        pyproject_table_macOS="""\
+        "pyproject_table_macOS": """\
 universal_build = true
 requires = [
     # Add your macOS-specific app requirements here
 ]
 """,
-        pyproject_table_linux="""\
+        "pyproject_table_linux": """\
 requires = [
     # Add your Linux-specific app requirements here
 ]
 """,
-        pyproject_table_linux_system_debian="""\
+        "pyproject_table_linux_system_debian": """\
 system_requires = [
     # Add any system packages needed at build the app here
 ]
@@ -291,7 +301,7 @@ system_runtime_requires = [
     # Add any system packages needed at runtime here
 ]
 """,
-        pyproject_table_linux_system_rhel="""\
+        "pyproject_table_linux_system_rhel": """\
 system_requires = [
     # Add any system packages needed at build the app here
 ]
@@ -300,7 +310,7 @@ system_runtime_requires = [
     # Add any system packages needed at runtime here
 ]
 """,
-        pyproject_table_linux_system_suse="""\
+        "pyproject_table_linux_system_suse": """\
 system_requires = [
     # Add any system packages needed at build the app here
 ]
@@ -309,7 +319,7 @@ system_runtime_requires = [
     # Add any system packages needed at runtime here
 ]
 """,
-        pyproject_table_linux_system_arch="""\
+        "pyproject_table_linux_system_arch": """\
 system_requires = [
     # Add any system packages needed at build the app here
 ]
@@ -318,26 +328,26 @@ system_runtime_requires = [
     # Add any system packages needed at runtime here
 ]
 """,
-        pyproject_table_linux_flatpak="""\
+        "pyproject_table_linux_flatpak": """\
 flatpak_runtime = "org.freedesktop.Platform"
 flatpak_runtime_version = "24.08"
 flatpak_sdk = "org.freedesktop.Sdk"
 """,
-        pyproject_table_windows="""\
+        "pyproject_table_windows": """\
 requires = [
     # Add your Windows-specific app requirements here
 ]
 """,
-        pyproject_table_iOS="""\
+        "pyproject_table_iOS": """\
 supported = false
 """,
-        pyproject_table_android="""\
+        "pyproject_table_android": """\
 supported = false
 """,
-        pyproject_table_web="""\
+        "pyproject_table_web": """\
 supported = false
 """,
-    )
+    }
 
 
 def test_pyside6_bootstrap(new_command):
@@ -354,8 +364,8 @@ def test_pyside6_bootstrap(new_command):
         project_overrides={},
     )
 
-    assert context == dict(
-        app_source="""\
+    assert context == {
+        "app_source": """\
 import importlib.metadata
 import sys
 
@@ -393,10 +403,10 @@ def main():
     main_window = {{ cookiecutter.class_name }}()
     sys.exit(app.exec())
 """,
-        pyproject_table_briefcase_app_extra_content="""
+        "pyproject_table_briefcase_app_extra_content": """
 requires = [
-    "PySide6-Essentials~=6.7",
-    # "PySide6-Addons~=6.7",
+    "PySide6-Essentials~=6.8",
+    # "PySide6-Addons~=6.8",
 ]
 test_requires = [
 {% if cookiecutter.test_framework == "pytest" %}
@@ -404,17 +414,19 @@ test_requires = [
 {% endif %}
 ]
 """,
-        pyproject_table_macOS="""\
+        "pyproject_table_macOS": """\
 universal_build = true
+# As of Pyside 6.8, PySide enforces a macOS 12 minimum on wheels.
+min_os_version = "12.0"
 requires = [
     "std-nslog~=1.0.3",
 ]
 """,
-        pyproject_table_linux="""\
+        "pyproject_table_linux": """\
 requires = [
 ]
 """,
-        pyproject_table_linux_system_debian="""\
+        "pyproject_table_linux_system_debian": """\
 system_requires = [
 ]
 
@@ -441,7 +453,7 @@ system_runtime_requires = [
     "libdbus-1-3",
 ]
 """,
-        pyproject_table_linux_system_rhel="""\
+        "pyproject_table_linux_system_rhel": """\
 system_requires = [
 ]
 
@@ -449,7 +461,7 @@ system_runtime_requires = [
     "qt6-qtbase-gui",
 ]
 """,
-        pyproject_table_linux_system_suse="""\
+        "pyproject_table_linux_system_suse": """\
 system_requires = [
 ]
 
@@ -458,7 +470,7 @@ system_runtime_requires = [
     "libQt6Gui6",
 ]
 """,
-        pyproject_table_linux_system_arch="""\
+        "pyproject_table_linux_system_arch": """\
 system_requires = [
 ]
 
@@ -466,7 +478,7 @@ system_runtime_requires = [
     "qt6-base",
 ]
 """,
-        pyproject_table_linux_appimage="""\
+        "pyproject_table_linux_appimage": """\
 manylinux = "manylinux_2_28"
 
 system_requires = [
@@ -476,25 +488,25 @@ system_requires = [
 linuxdeploy_plugins = [
 ]
 """,
-        pyproject_table_linux_flatpak="""\
+        "pyproject_table_linux_flatpak": """\
 flatpak_runtime = "org.kde.Platform"
-flatpak_runtime_version = "6.7"
+flatpak_runtime_version = "6.9"
 flatpak_sdk = "org.kde.Sdk"
 """,
-        pyproject_table_windows="""\
+        "pyproject_table_windows": """\
 requires = [
 ]
 """,
-        pyproject_table_iOS="""\
+        "pyproject_table_iOS": """\
 supported = false
 """,
-        pyproject_table_android="""\
+        "pyproject_table_android": """\
 supported = false
 """,
-        pyproject_table_web="""\
+        "pyproject_table_web": """\
 supported = false
 """,
-    )
+    }
 
 
 def test_pygame_bootstrap(new_command):
@@ -511,8 +523,8 @@ def test_pygame_bootstrap(new_command):
         project_overrides={},
     )
 
-    assert context == dict(
-        app_source="""\
+    assert context == {
+        "app_source": """\
 import importlib.metadata
 import os
 import sys
@@ -558,7 +570,7 @@ def main():
 
     pygame.quit()
 """,
-        pyproject_table_briefcase_app_extra_content="""
+        "pyproject_table_briefcase_app_extra_content": """
 requires = [
     "pygame~=2.6",
 ]
@@ -568,45 +580,45 @@ test_requires = [
 {% endif %}
 ]
 """,
-        pyproject_table_macOS="""\
+        "pyproject_table_macOS": """\
 universal_build = true
 requires = [
     "std-nslog~=1.0.3",
 ]
 """,
-        pyproject_table_linux="""\
+        "pyproject_table_linux": """\
 requires = [
 ]
 """,
-        pyproject_table_linux_system_debian="""\
+        "pyproject_table_linux_system_debian": """\
 system_requires = [
 ]
 
 system_runtime_requires = [
 ]
 """,
-        pyproject_table_linux_system_rhel="""\
+        "pyproject_table_linux_system_rhel": """\
 system_requires = [
 ]
 
 system_runtime_requires = [
 ]
 """,
-        pyproject_table_linux_system_suse="""\
+        "pyproject_table_linux_system_suse": """\
 system_requires = [
 ]
 
 system_runtime_requires = [
 ]
 """,
-        pyproject_table_linux_system_arch="""\
+        "pyproject_table_linux_system_arch": """\
 system_requires = [
 ]
 
 system_runtime_requires = [
 ]
 """,
-        pyproject_table_linux_appimage="""\
+        "pyproject_table_linux_appimage": """\
 manylinux = "manylinux_2_28"
 
 system_requires = [
@@ -615,25 +627,25 @@ system_requires = [
 linuxdeploy_plugins = [
 ]
 """,
-        pyproject_table_linux_flatpak="""\
+        "pyproject_table_linux_flatpak": """\
 flatpak_runtime = "org.freedesktop.Platform"
 flatpak_runtime_version = "24.08"
 flatpak_sdk = "org.freedesktop.Sdk"
 """,
-        pyproject_table_windows="""\
+        "pyproject_table_windows": """\
 requires = [
 ]
 """,
-        pyproject_table_iOS="""\
+        "pyproject_table_iOS": """\
 supported = false
 """,
-        pyproject_table_android="""\
+        "pyproject_table_android": """\
 supported = false
 """,
-        pyproject_table_web="""\
+        "pyproject_table_web": """\
 supported = false
 """,
-    )
+    }
 
 
 def test_no_bootstrap(new_command):
@@ -650,20 +662,20 @@ def test_no_bootstrap(new_command):
         project_overrides={},
     )
 
-    assert context == dict(
-        app_source="""\
+    assert context == {
+        "app_source": """\
 
 def main():
     # Your app logic goes here
     print("Hello, World.")
 """,
-        app_start_source="""\
+        "app_start_source": """\
 from {{ cookiecutter.module_name }}.app import main
 
 if __name__ == "__main__":
     main()
 """,
-        pyproject_table_briefcase_app_extra_content="""
+        "pyproject_table_briefcase_app_extra_content": """
 requires = [
     # Add your cross-platform app requirements here
 ]
@@ -671,18 +683,18 @@ test_requires = [
     # Add your cross-platform test requirements here
 ]
 """,
-        pyproject_table_macOS="""\
+        "pyproject_table_macOS": """\
 universal_build = true
 requires = [
     # Add your macOS-specific app requirements here
 ]
 """,
-        pyproject_table_linux="""\
+        "pyproject_table_linux": """\
 requires = [
     # Add your Linux-specific app requirements here
 ]
 """,
-        pyproject_table_linux_system_debian="""\
+        "pyproject_table_linux_system_debian": """\
 system_requires = [
     # Add any system packages needed at build the app here
 ]
@@ -691,7 +703,7 @@ system_runtime_requires = [
     # Add any system packages needed at runtime here
 ]
 """,
-        pyproject_table_linux_system_rhel="""\
+        "pyproject_table_linux_system_rhel": """\
 system_requires = [
     # Add any system packages needed at build the app here
 ]
@@ -700,7 +712,7 @@ system_runtime_requires = [
     # Add any system packages needed at runtime here
 ]
 """,
-        pyproject_table_linux_system_suse="""\
+        "pyproject_table_linux_system_suse": """\
 system_requires = [
     # Add any system packages needed at build the app here
 ]
@@ -709,7 +721,7 @@ system_runtime_requires = [
     # Add any system packages needed at runtime here
 ]
 """,
-        pyproject_table_linux_system_arch="""\
+        "pyproject_table_linux_system_arch": """\
 system_requires = [
     # Add any system packages needed at build the app here
 ]
@@ -718,32 +730,32 @@ system_runtime_requires = [
     # Add any system packages needed at runtime here
 ]
 """,
-        pyproject_table_linux_flatpak="""\
+        "pyproject_table_linux_flatpak": """\
 flatpak_runtime = "org.freedesktop.Platform"
 flatpak_runtime_version = "24.08"
 flatpak_sdk = "org.freedesktop.Sdk"
 """,
-        pyproject_table_windows="""\
+        "pyproject_table_windows": """\
 requires = [
     # Add your Windows-specific app requirements here
 ]
 """,
-        pyproject_table_iOS="""\
+        "pyproject_table_iOS": """\
 requires = [
     # Add your iOS-specific app requirements here
 ]
 """,
-        pyproject_table_android="""\
+        "pyproject_table_android": """\
 requires = [
     # Add your Android-specific app requirements here
 ]
 """,
-        pyproject_table_web="""\
+        "pyproject_table_web": """\
 requires = [
     # Add your web-specific app requirements here
 ]
 """,
-    )
+    }
 
 
 def test_custom_bootstrap(
@@ -776,10 +788,10 @@ def test_custom_bootstrap(
         briefcase.commands.new,
         "get_gui_bootstraps",
         MagicMock(
-            return_value=dict(
+            return_value={
                 **mock_builtin_bootstraps,
                 **{"Custom GUI": GuiBootstrap},
-            ),
+            },
         ),
     )
 
@@ -794,9 +806,9 @@ def test_custom_bootstrap(
         project_overrides={"custom_override": "other"},
     )
 
-    assert context == dict(
-        custom_context="value",
-        custom_override="other",
-        requires="toga",
-        platform="bsd",
-    )
+    assert context == {
+        "custom_context": "value",
+        "custom_override": "other",
+        "requires": "toga",
+        "platform": "bsd",
+    }
