@@ -1,3 +1,7 @@
+import pytest
+
+from briefcase.exceptions import BriefcaseCommandError
+
 from ...utils import create_file
 
 
@@ -41,7 +45,7 @@ def test_no_args_package_one_app(package_command, first_app, tmp_path):
     assert first_app.packaging_format == "pkg"
 
     # The dist folder has been created.
-    assert tmp_path / "base_path/dist"
+    assert (tmp_path / "base_path/dist").exists()
 
 
 def test_package_one_explicit_app(package_command, first_app, second_app, tmp_path):
@@ -86,7 +90,7 @@ def test_package_one_explicit_app(package_command, first_app, second_app, tmp_pa
     assert not hasattr(second_app, "packaging_format")
 
     # The dist folder has been created.
-    assert tmp_path / "base_path/dist"
+    assert (tmp_path / "base_path/dist").exists()
 
 
 def test_no_args_package_two_app(package_command, first_app, second_app, tmp_path):
@@ -147,7 +151,7 @@ def test_no_args_package_two_app(package_command, first_app, second_app, tmp_pat
     assert second_app.packaging_format == "pkg"
 
     # The dist folder has been created.
-    assert tmp_path / "base_path/dist"
+    assert (tmp_path / "base_path/dist").exists()
 
 
 def test_identity_arg_package_one_app(package_command, first_app, tmp_path):
@@ -191,7 +195,7 @@ def test_identity_arg_package_one_app(package_command, first_app, tmp_path):
     assert first_app.packaging_format == "pkg"
 
     # The dist folder has been created.
-    assert tmp_path / "base_path/dist"
+    assert (tmp_path / "base_path/dist").exists()
 
 
 def test_adhoc_sign_package_one_app(package_command, first_app, tmp_path):
@@ -235,7 +239,7 @@ def test_adhoc_sign_package_one_app(package_command, first_app, tmp_path):
     assert first_app.packaging_format == "pkg"
 
     # The dist folder has been created.
-    assert tmp_path / "base_path/dist"
+    assert (tmp_path / "base_path/dist").exists()
 
 
 def test_adhoc_sign_args_package_two_app(
@@ -301,7 +305,7 @@ def test_adhoc_sign_args_package_two_app(
     assert second_app.packaging_format == "pkg"
 
     # The dist folder has been created.
-    assert tmp_path / "base_path/dist"
+    assert (tmp_path / "base_path/dist").exists()
 
 
 def test_identity_sign_args_package_two_app(
@@ -365,7 +369,7 @@ def test_identity_sign_args_package_two_app(
     assert second_app.packaging_format == "pkg"
 
     # The dist folder has been created.
-    assert tmp_path / "base_path/dist"
+    assert (tmp_path / "base_path/dist").exists()
 
 
 def test_package_alternate_format(package_command, first_app, tmp_path):
@@ -408,7 +412,7 @@ def test_package_alternate_format(package_command, first_app, tmp_path):
     assert first_app.packaging_format == "box"
 
     # The dist folder has been created.
-    assert tmp_path / "base_path/dist"
+    assert (tmp_path / "base_path/dist").exists()
 
 
 def test_create_before_package(package_command, first_app_config, tmp_path):
@@ -471,7 +475,7 @@ def test_create_before_package(package_command, first_app_config, tmp_path):
     assert first_app_config.packaging_format == "pkg"
 
     # The dist folder has been created.
-    assert tmp_path / "base_path/dist"
+    assert (tmp_path / "base_path/dist").exists()
 
 
 def test_update_package_one_app(package_command, first_app, tmp_path):
@@ -537,7 +541,7 @@ def test_update_package_one_app(package_command, first_app, tmp_path):
     assert first_app.packaging_format == "pkg"
 
     # The dist folder has been created.
-    assert tmp_path / "base_path/dist"
+    assert (tmp_path / "base_path/dist").exists()
 
 
 def test_update_package_two_app(package_command, first_app, second_app, tmp_path):
@@ -651,7 +655,7 @@ def test_update_package_two_app(package_command, first_app, second_app, tmp_path
     assert second_app.packaging_format == "pkg"
 
     # The dist folder has been created.
-    assert tmp_path / "base_path/dist"
+    assert (tmp_path / "base_path/dist").exists()
 
 
 def test_build_before_package(package_command, first_app_unbuilt, tmp_path):
@@ -704,7 +708,7 @@ def test_build_before_package(package_command, first_app_unbuilt, tmp_path):
     assert first_app_unbuilt.packaging_format == "pkg"
 
     # The dist folder has been created.
-    assert tmp_path / "base_path/dist"
+    assert (tmp_path / "base_path/dist").exists()
 
 
 def test_already_packaged(package_command, first_app, tmp_path):
@@ -751,10 +755,318 @@ def test_already_packaged(package_command, first_app, tmp_path):
     assert first_app.packaging_format == "pkg"
 
     # The dist folder still exists
-    assert tmp_path / "base_path/dist"
+    assert (tmp_path / "base_path/dist").exists()
 
     # But the artefact has been deleted.
     # NOTE: This is a testing quirk - because we're mocking the
     # package_app() call, no new artefact is created; the absence
     # of this file shows that the old one has been deleted.
     assert not artefact_path.exists()
+
+
+# Parametrize both --apps/-a flags
+@pytest.mark.parametrize("app_flags", ["--app", "-a"])
+def test_package_app_single(package_command, first_app, second_app, app_flags):
+    """If the --app or -a flag is used, only the selected app is packaged."""
+    # Add two apps
+    package_command.apps = {
+        "first": first_app,
+        "second": second_app,
+    }
+
+    # Configure command line options with the parameterized flag
+    options, _ = package_command.parse_options([app_flags, "first"])
+
+    # Run the package command
+    package_command(**options)
+
+    # Only the selected app is packaged
+    assert package_command.actions == [
+        # Host OS is verified
+        ("verify-host",),
+        # Tools are verified
+        ("verify-tools",),
+        # App config has been finalized
+        ("finalize-app-config", "first"),
+        ("finalize-app-config", "second"),
+        # App template is verified
+        ("verify-app-template", "first"),
+        # App tools are verified
+        ("verify-app-tools", "first"),
+        # Package the app
+        (
+            "package",
+            "first",
+            {
+                "adhoc_sign": False,
+                "identity": None,
+            },
+        ),
+    ]
+
+
+def test_package_app_invalid(package_command, first_app, second_app):
+    """If an invalid app name is passed to --app, raise an error."""
+    # Add two apps
+    package_command.apps = {
+        "first": first_app,
+        "second": second_app,
+    }
+
+    # Configure the --app option with an invalid app
+    options, _ = package_command.parse_options(["--app", "invalid"])
+
+    # Running the command should raise an error
+    with pytest.raises(
+        BriefcaseCommandError,
+        match=r"App 'invalid' does not exist in this project.",
+    ):
+        package_command(**options)
+
+
+def test_package_app_none_defined(package_command):
+    """If no apps are defined, do nothing."""
+    # No apps defined
+    package_command.apps = {}
+
+    # Configure no command line options
+    options, _ = package_command.parse_options([])
+
+    # Run the package command
+    result = package_command(**options)
+
+    # The right sequence of things will be done
+    assert result is None
+    assert package_command.actions == [
+        # Host OS is verified
+        ("verify-host",),
+        # Tools are verified
+        ("verify-tools",),
+    ]
+
+
+def test_package_app_all_flags(package_command, first_app, second_app):
+    """Verify that all package-related flags work correctly with -a."""
+    # Add a single app
+    package_command.apps = {
+        "first": first_app,
+        "second": second_app,
+    }
+
+    # Configure command line options with all available flags
+    options, _ = package_command.parse_options(
+        [
+            "-a",
+            "first",
+            "--update",
+            "--packaging-format",
+            "pkg",
+            "--adhoc-sign",
+        ]
+    )
+    app_name = options.pop("app_name")
+
+    # Run the package command
+    package_command(app_name=app_name, **options)
+
+    # The right sequence of things will be done
+    assert package_command.actions == [
+        # Host OS is verified
+        ("verify-host",),
+        # Tools are verified
+        ("verify-tools",),
+        # App config has been finalized
+        ("finalize-app-config", "first"),
+        ("finalize-app-config", "second"),
+        # App is updated with all update options
+        (
+            "update",
+            "first",
+            {
+                "adhoc_sign": True,
+                "identity": None,
+                "update_requirements": True,
+                "update_resources": True,
+                "update_support": True,
+            },
+        ),
+        # App is built with update state
+        (
+            "build",
+            "first",
+            {
+                "adhoc_sign": True,
+                "identity": None,
+                "update_state": "first",
+            },
+        ),
+        # App template is verified
+        ("verify-app-template", "first"),
+        # App tools are verified
+        ("verify-app-tools", "first"),
+        # App is packaged with the full state and adhoc signing
+        (
+            "package",
+            "first",
+            {
+                "adhoc_sign": True,
+                "identity": None,
+                "update_state": "first",
+                "build_state": "first",
+            },
+        ),
+    ]
+
+
+def test_package_external_not_supported(package_command, first_app, tmp_path):
+    """If the backend doesn't explicitly support external packaging, an error is
+    raised."""
+    # Add a single external app
+    package_command.apps = {
+        "first": first_app,
+    }
+    first_app.external_package_path = "path/to/package"
+    first_app.sources = None
+
+    # Configure no command line arguments
+    options, _ = package_command.parse_options([])
+
+    # Run the build command on a specific app
+    with pytest.raises(
+        BriefcaseCommandError,
+        match=r"Briefcase cannot package external Tester apps in Dummy format.",
+    ):
+        package_command(first_app, **options)
+
+    # The right sequence of things will be done
+    assert package_command.actions == [
+        # Host OS is verified
+        ("verify-host",),
+        # Tools are verified
+        ("verify-tools",),
+        # App config has been finalized
+        ("finalize-app-config", "first"),
+    ]
+
+    # The dist folder has not been created.
+    assert not (tmp_path / "base_path/dist").exists()
+
+
+def test_package_external_app(package_command, first_app, tmp_path):
+    """An external app can be packaged."""
+    # Enable external packaging
+    package_command.supports_external_packaging = True
+
+    # Add a single external app
+    package_command.apps = {
+        "first": first_app,
+    }
+    first_app.external_package_path = "path/to/package"
+    first_app.sources = None
+
+    # Configure no command line arguments
+    options, _ = package_command.parse_options([])
+
+    # Run the build command on a specific app
+    package_command(first_app, **options)
+
+    # The right sequence of things will be done
+    assert package_command.actions == [
+        # Host OS is verified
+        ("verify-host",),
+        # Tools are verified
+        ("verify-tools",),
+        # App config has been finalized
+        ("finalize-app-config", "first"),
+        # App has been created
+        (
+            "create",
+            "first",
+            {
+                "adhoc_sign": False,
+                "identity": None,
+            },
+        ),
+        # App template is verified
+        ("verify-app-template", "first"),
+        # App tools are verified for app
+        ("verify-app-tools", "first"),
+        # Package the first app
+        (
+            "package",
+            "first",
+            {
+                "adhoc_sign": False,
+                "create_state": "first",
+                "identity": None,
+            },
+        ),
+    ]
+
+    # Packaging format has been annotated on the first app, not the second.
+    assert first_app.packaging_format == "pkg"
+
+    # The dist folder has been created.
+    assert (tmp_path / "base_path/dist").exists()
+
+
+def test_create_before_package_external_app(
+    package_command,
+    first_app_config,
+    tmp_path,
+):
+    """If an external app hasn't been created before packaging, it is created first."""
+    # Enable external packaging
+    package_command.supports_external_packaging = True
+
+    # Add a single external app
+    package_command.apps = {
+        "first": first_app_config,
+    }
+    first_app_config.external_package_path = "path/to/package"
+    first_app_config.sources = None
+
+    # Configure no command line arguments
+    options, _ = package_command.parse_options([])
+
+    # Run the build command on a specific app
+    package_command(first_app_config, **options)
+
+    # The right sequence of things will be done
+    assert package_command.actions == [
+        # Host OS is verified
+        ("verify-host",),
+        # Tools are verified
+        ("verify-tools",),
+        # App config has been finalized
+        ("finalize-app-config", "first"),
+        # App has been created
+        (
+            "create",
+            "first",
+            {
+                "adhoc_sign": False,
+                "identity": None,
+            },
+        ),
+        # App template is verified
+        ("verify-app-template", "first"),
+        # App tools are verified for app
+        ("verify-app-tools", "first"),
+        # Package the first app
+        (
+            "package",
+            "first",
+            {
+                "adhoc_sign": False,
+                "create_state": "first",
+                "identity": None,
+            },
+        ),
+    ]
+
+    # Packaging format has been annotated on the first app, not the second.
+    assert first_app_config.packaging_format == "pkg"
+
+    # The dist folder has been created.
+    assert (tmp_path / "base_path/dist").exists()
