@@ -29,7 +29,7 @@ def test_no_args_one_app(run_command, first_app):
         # App tools are verified
         ("verify-app-tools", "first"),
         # Run the first app
-        ("run", "first", {"test_mode": False, "passthrough": []}),
+        ("run", "first", False, {"passthrough": []}),
     ]
 
 
@@ -60,7 +60,7 @@ def test_no_args_one_app_with_passthrough(run_command, first_app):
         # App tools have been verified
         ("verify-app-tools", "first"),
         # Run the first app
-        ("run", "first", {"test_mode": False, "passthrough": ["foo", "--bar"]}),
+        ("run", "first", False, {"passthrough": ["foo", "--bar"]}),
     ]
 
 
@@ -109,7 +109,7 @@ def test_with_arg_one_app(run_command, first_app):
         # App tools are verified
         ("verify-app-tools", "first"),
         # Run the first app
-        ("run", "first", {"test_mode": False, "passthrough": []}),
+        ("run", "first", False, {"passthrough": []}),
     ]
 
 
@@ -140,7 +140,7 @@ def test_with_arg_two_apps(run_command, first_app, second_app):
         # App tools have been verified
         ("verify-app-tools", "second"),
         # Run the second app
-        ("run", "second", {"test_mode": False, "passthrough": []}),
+        ("run", "second", False, {"passthrough": []}),
     ]
 
 
@@ -190,8 +190,8 @@ def test_create_app_before_start(run_command, first_app_config):
         (
             "build",
             "first",
+            False,
             {
-                "test_mode": False,
                 "update": False,
                 "update_requirements": False,
                 "update_resources": False,
@@ -208,7 +208,8 @@ def test_create_app_before_start(run_command, first_app_config):
         (
             "run",
             "first",
-            {"build_state": "first", "test_mode": False, "passthrough": []},
+            False,
+            {"build_state": "first", "passthrough": []},
         ),
     ]
 
@@ -238,8 +239,8 @@ def test_build_app_before_start(run_command, first_app_unbuilt):
         (
             "build",
             "first",
+            False,
             {
-                "test_mode": False,
                 "update": False,
                 "update_requirements": False,
                 "update_resources": False,
@@ -256,7 +257,8 @@ def test_build_app_before_start(run_command, first_app_unbuilt):
         (
             "run",
             "first",
-            {"build_state": "first", "test_mode": False, "passthrough": []},
+            False,
+            {"build_state": "first", "passthrough": []},
         ),
     ]
 
@@ -286,8 +288,8 @@ def test_update_app(run_command, first_app):
         (
             "build",
             "first",
+            False,
             {
-                "test_mode": False,
                 "update": True,
                 "update_requirements": False,
                 "update_resources": False,
@@ -304,7 +306,8 @@ def test_update_app(run_command, first_app):
         (
             "run",
             "first",
-            {"build_state": "first", "test_mode": False, "passthrough": []},
+            False,
+            {"build_state": "first", "passthrough": []},
         ),
     ]
 
@@ -334,8 +337,8 @@ def test_update_app_requirements(run_command, first_app):
         (
             "build",
             "first",
+            False,
             {
-                "test_mode": False,
                 "update": False,
                 "update_requirements": True,
                 "update_resources": False,
@@ -352,7 +355,8 @@ def test_update_app_requirements(run_command, first_app):
         (
             "run",
             "first",
-            {"build_state": "first", "test_mode": False, "passthrough": []},
+            False,
+            {"build_state": "first", "passthrough": []},
         ),
     ]
 
@@ -382,8 +386,8 @@ def test_update_app_resources(run_command, first_app):
         (
             "build",
             "first",
+            False,
             {
-                "test_mode": False,
                 "update": False,
                 "update_requirements": False,
                 "update_resources": True,
@@ -400,7 +404,8 @@ def test_update_app_resources(run_command, first_app):
         (
             "run",
             "first",
-            {"build_state": "first", "test_mode": False, "passthrough": []},
+            False,
+            {"build_state": "first", "passthrough": []},
         ),
     ]
 
@@ -430,8 +435,8 @@ def test_update_app_support(run_command, first_app):
         (
             "build",
             "first",
+            False,
             {
-                "test_mode": False,
                 "update": False,
                 "update_requirements": False,
                 "update_resources": False,
@@ -448,7 +453,8 @@ def test_update_app_support(run_command, first_app):
         (
             "run",
             "first",
-            {"build_state": "first", "test_mode": False, "passthrough": []},
+            False,
+            {"build_state": "first", "passthrough": []},
         ),
     ]
 
@@ -478,8 +484,8 @@ def test_update_app_stub(run_command, first_app):
         (
             "build",
             "first",
+            False,
             {
-                "test_mode": False,
                 "update": False,
                 "update_requirements": False,
                 "update_resources": False,
@@ -496,7 +502,8 @@ def test_update_app_stub(run_command, first_app):
         (
             "run",
             "first",
-            {"build_state": "first", "test_mode": False, "passthrough": []},
+            False,
+            {"build_state": "first", "passthrough": []},
         ),
     ]
 
@@ -527,8 +534,8 @@ def test_update_unbuilt_app(run_command, first_app_unbuilt):
         (
             "build",
             "first",
+            False,
             {
-                "test_mode": False,
                 "update": True,
                 "update_requirements": False,
                 "update_resources": False,
@@ -545,7 +552,8 @@ def test_update_unbuilt_app(run_command, first_app_unbuilt):
         (
             "run",
             "first",
-            {"build_state": "first", "test_mode": False, "passthrough": []},
+            False,
+            {"build_state": "first", "passthrough": []},
         ),
     ]
 
@@ -576,8 +584,8 @@ def test_update_non_existent(run_command, first_app_config):
         (
             "build",
             "first",
+            False,
             {
-                "test_mode": False,
                 "update": True,
                 "update_requirements": False,
                 "update_resources": False,
@@ -594,7 +602,8 @@ def test_update_non_existent(run_command, first_app_config):
         (
             "run",
             "first",
-            {"build_state": "first", "test_mode": False, "passthrough": []},
+            False,
+            {"build_state": "first", "passthrough": []},
         ),
     ]
 
@@ -624,8 +633,8 @@ def test_test_mode_existing_app(run_command, first_app):
         (
             "build",
             "first",
+            True,
             {
-                "test_mode": True,
                 "update": False,
                 "update_requirements": False,
                 "update_resources": False,
@@ -642,7 +651,8 @@ def test_test_mode_existing_app(run_command, first_app):
         (
             "run",
             "first",
-            {"build_state": "first", "test_mode": True, "passthrough": []},
+            True,
+            {"build_state": "first", "passthrough": []},
         ),
     ]
 
@@ -672,8 +682,8 @@ def test_test_mode_existing_app_with_passthrough(run_command, first_app):
         (
             "build",
             "first",
+            True,
             {
-                "test_mode": True,
                 "update": False,
                 "update_requirements": False,
                 "update_resources": False,
@@ -690,9 +700,9 @@ def test_test_mode_existing_app_with_passthrough(run_command, first_app):
         (
             "run",
             "first",
+            True,
             {
                 "build_state": "first",
-                "test_mode": True,
                 "passthrough": ["foo", "--bar"],
             },
         ),
@@ -729,7 +739,8 @@ def test_test_mode_existing_app_no_update(run_command, first_app):
         (
             "run",
             "first",
-            {"test_mode": True, "passthrough": []},
+            True,
+            {"passthrough": []},
         ),
     ]
 
@@ -759,8 +770,8 @@ def test_test_mode_existing_app_update_requirements(run_command, first_app):
         (
             "build",
             "first",
+            True,
             {
-                "test_mode": True,
                 "update": False,
                 "update_requirements": True,
                 "update_resources": False,
@@ -777,7 +788,8 @@ def test_test_mode_existing_app_update_requirements(run_command, first_app):
         (
             "run",
             "first",
-            {"build_state": "first", "test_mode": True, "passthrough": []},
+            True,
+            {"build_state": "first", "passthrough": []},
         ),
     ]
 
@@ -807,8 +819,8 @@ def test_test_mode_existing_app_update_resources(run_command, first_app):
         (
             "build",
             "first",
+            True,
             {
-                "test_mode": True,
                 "update": False,
                 "update_requirements": False,
                 "update_resources": True,
@@ -825,7 +837,8 @@ def test_test_mode_existing_app_update_resources(run_command, first_app):
         (
             "run",
             "first",
-            {"build_state": "first", "test_mode": True, "passthrough": []},
+            True,
+            {"build_state": "first", "passthrough": []},
         ),
     ]
 
@@ -855,8 +868,8 @@ def test_test_mode_update_existing_app(run_command, first_app):
         (
             "build",
             "first",
+            True,
             {
-                "test_mode": True,
                 "update": True,
                 "update_requirements": False,
                 "update_resources": False,
@@ -873,7 +886,8 @@ def test_test_mode_update_existing_app(run_command, first_app):
         (
             "run",
             "first",
-            {"build_state": "first", "test_mode": True, "passthrough": []},
+            True,
+            {"build_state": "first", "passthrough": []},
         ),
     ]
 
@@ -903,8 +917,8 @@ def test_test_mode_non_existent(run_command, first_app_config):
         (
             "build",
             "first",
+            True,
             {
-                "test_mode": True,
                 "update": False,
                 "update_requirements": False,
                 "update_resources": False,
@@ -921,6 +935,29 @@ def test_test_mode_non_existent(run_command, first_app_config):
         (
             "run",
             "first",
-            {"build_state": "first", "test_mode": True, "passthrough": []},
+            True,
+            {"build_state": "first", "passthrough": []},
         ),
     ]
+
+
+def test_run_external_app(run_command, first_app):
+    """If the user requests a run an external app, an error is raised."""
+    # Add an apps
+    run_command.apps = {
+        "first": first_app,
+    }
+
+    # Make first_app an external app
+    first_app.sources = None
+    first_app.external_package_path = "path/to/package"
+
+    # Configure no command line options
+    options, _ = run_command.parse_options([])
+
+    # Run the build command
+    with pytest.raises(
+        BriefcaseCommandError,
+        match=r"'first' is declared as an external app",
+    ):
+        run_command(**options)
