@@ -1,7 +1,6 @@
 import pytest
 
 from briefcase.console import InputDisabled
-from tests.utils import default_rich_prompt
 
 
 @pytest.mark.parametrize(
@@ -12,7 +11,7 @@ from tests.utils import default_rich_prompt
     ],
 )
 def test_text_question(console, value, expected):
-    console._console_impl.input.return_value = value
+    console.values = [value]
 
     actual = console.input_text(
         prompt="> ",
@@ -20,9 +19,7 @@ def test_text_question(console, value, expected):
     )
 
     assert actual == expected
-    console._console_impl.input.assert_called_once_with(
-        default_rich_prompt("> "), markup=True
-    )
+    assert console.prompts == ["> "]
 
 
 def test_disabled(disabled_console):
@@ -33,7 +30,7 @@ def test_disabled(disabled_console):
     )
 
     assert actual == "Default"
-    disabled_console._console_impl.input.assert_not_called()
+    assert disabled_console.prompts == []
 
 
 def test_disabled_no_default(disabled_console):
@@ -44,4 +41,4 @@ def test_disabled_no_default(disabled_console):
             default=None,
         )
 
-    disabled_console._console_impl.input.assert_not_called()
+    assert disabled_console.prompts == []
