@@ -1,11 +1,13 @@
 import os
 import platform
 import shutil
+import ssl
 import stat
 from collections.abc import Iterable, Iterator
 from pathlib import Path
 from unittest import mock
 
+import httpcore
 import httpx
 import pytest
 
@@ -31,7 +33,8 @@ class _IteratorByteSteam(httpx.SyncByteStream):
     """Shim that satisfies ``httpx.Response`` ``stream`` parameter type.
 
     Cannot be replaced by any ``Iterable[bytes]`` because the base class requires
-    an explicit finalization method ``close``."""
+    an explicit finalization method ``close``.
+    """
 
     def __init__(self, iterable: Iterable[bytes]) -> None:
         self.iterable = iterable
@@ -46,15 +49,19 @@ def _make_httpx_response(
     status_code: int,
     stream: list[bytes],
     method: str = "GET",
-    headers: dict = {},
+    headers: dict | None = None,
 ) -> httpx.Response:
-    """Create a real ``httpx.Response`` with key methods wrapped by ``mock.Mock`` for spying.
+    """Create a real ``httpx.Response`` with key methods wrapped by ``mock.Mock`` for
+    spying.
 
     Wrapped methods:
         response.read
         response.iter_bytes
         response.headers.get
     """
+    if headers is None:
+        headers = {}
+
     response = httpx.Response(
         request=httpx.Request(
             method=method,
@@ -157,6 +164,7 @@ def test_new_download_oneshot(mock_tools, file_perms, url, content_disposition):
         "GET",
         "https://example.com/support?useful=Yes",
         follow_redirects=True,
+        verify=mock_tools.file.ssl_context,
     )
     response.headers.get.assert_called_with("content-length")
     response.read.assert_called_once()
@@ -184,7 +192,8 @@ def test_new_download_oneshot(mock_tools, file_perms, url, content_disposition):
 
 
 def test_new_download_chunked(mock_tools, file_perms):
-    """If a content-length is provided, ``File`` streams the response rather than downloading it all at once."""
+    """If a content-length is provided, ``File`` streams the response rather than
+    downloading it all at once."""
     response = _make_httpx_response(
         method="GET",
         url="https://example.com/path/to/something.zip",
@@ -209,6 +218,7 @@ def test_new_download_chunked(mock_tools, file_perms):
         "GET",
         "https://example.com/support?useful=Yes",
         follow_redirects=True,
+        verify=mock_tools.file.ssl_context,
     )
     response.headers.get.assert_called_with("content-length")
     response.iter_bytes.assert_called_once_with(chunk_size=1048576)
@@ -239,8 +249,8 @@ def test_new_download_chunked(mock_tools, file_perms):
 def test_already_downloaded(mock_tools):
     """If the file already exists on disk, it isn't re-downloaded.
 
-    The request is still made to derive the filename, but the content
-    is never streamed."""
+    The request is still made to derive the filename, but the content is never streamed.
+    """
 
     # Create an existing file
     existing_file = mock_tools.base_path / "something.zip"
@@ -272,6 +282,7 @@ def test_already_downloaded(mock_tools):
         "GET",
         url,
         follow_redirects=True,
+        verify=mock_tools.file.ssl_context,
     )
 
     # The request's Content-Disposition header is consumed to
@@ -290,7 +301,7 @@ def test_already_downloaded(mock_tools):
 
 
 def test_missing_resource(mock_tools):
-    """MissingNetworkResourceError raises for 404 status code"""
+    """MissingNetworkResourceError raises for 404 status code."""
     url = "https://example.com/something.zip?useful=Yes"
     response = _make_httpx_response(
         url=url,
@@ -312,6 +323,7 @@ def test_missing_resource(mock_tools):
         "GET",
         url,
         follow_redirects=True,
+        verify=mock_tools.file.ssl_context,
     )
     response.headers.get.assert_not_called()
 
@@ -325,7 +337,7 @@ def test_missing_resource(mock_tools):
 
 
 def test_bad_resource(mock_tools):
-    """BadNetworkResourceError raises for non-200 status code"""
+    """BadNetworkResourceError raises for non-200 status code."""
     url = "https://example.com/something.zip?useful=Yes"
     response = _make_httpx_response(
         status_code=500,
@@ -347,6 +359,7 @@ def test_bad_resource(mock_tools):
         "GET",
         url,
         follow_redirects=True,
+        verify=mock_tools.file.ssl_context,
     )
     response.headers.get.assert_not_called()
 
@@ -360,8 +373,8 @@ def test_bad_resource(mock_tools):
 
 
 def test_iter_bytes_connection_error(mock_tools):
-    """NetworkFailure raised if response.iter_bytes() errors
-    and cleans up temporary files."""
+    """NetworkFailure raised if response.iter_bytes() errors and cleans up temporary
+    files."""
     url = "https://example.com/something.zip?useful=Yes"
     response = _make_httpx_response(
         status_code=200,
@@ -385,6 +398,7 @@ def test_iter_bytes_connection_error(mock_tools):
         "GET",
         "https://example.com/something.zip?useful=Yes",
         follow_redirects=True,
+        verify=mock_tools.file.ssl_context,
     )
     response.headers.get.assert_called_with("content-length")
 
@@ -426,6 +440,7 @@ def test_connection_error(mock_tools):
         "GET",
         url,
         follow_redirects=True,
+        verify=mock_tools.file.ssl_context,
     )
 
     # The file doesn't exist as a result of the download failure
@@ -462,6 +477,118 @@ def test_redirect_connection_error(mock_tools):
         "GET",
         "https://example.com/something.zip?useful=Yes",
         follow_redirects=True,
+        verify=mock_tools.file.ssl_context,
+    )
+
+    # The file doesn't exist as a result of the download failure
+    assert not (mock_tools.base_path / "something.zip").exists()
+
+    # Temporary file was not created, moved, or deleted
+    mock_tools.shutil.move.assert_not_called()
+    mock_tools.os.chmod.assert_not_called()
+    mock_tools.os.remove.assert_not_called()
+
+
+def test_ssl_verification_error(mock_tools):
+    """NetworkFailure is raised if the request fails due to SSL."""
+    # Mock an SSL verification error
+    error = httpx.ConnectError("connection error")
+    error.__context__ = httpcore.ConnectError()
+    error.__context__.__context__ = ssl.SSLCertVerificationError()
+    mock_tools.httpx.stream.side_effect = [error]
+
+    # Download the file
+    with pytest.raises(
+        NetworkFailure,
+        match=(
+            r"a connection to the server could not be established "
+            r"due to a certificate verification problem"
+        ),
+    ):
+        mock_tools.file.download(
+            url="https://example.com/something.zip",
+            download_path=mock_tools.base_path,
+        )
+
+    # httpx.stream has been invoked, but nothing else.
+    mock_tools.httpx.stream.assert_called_with(
+        "GET",
+        "https://example.com/something.zip",
+        follow_redirects=True,
+        verify=mock_tools.file.ssl_context,
+    )
+
+    # The file doesn't exist as a result of the download failure
+    assert not (mock_tools.base_path / "something.zip").exists()
+
+    # Temporary file was not created, moved, or deleted
+    mock_tools.shutil.move.assert_not_called()
+    mock_tools.os.chmod.assert_not_called()
+    mock_tools.os.remove.assert_not_called()
+
+
+def test_unknown_httpcore_connectionerror(mock_tools):
+    """NetworkFailure is raised if an unknown core connection error occurs."""
+    # Mock a connection error at the level of httpcore
+    error = httpx.ConnectError("connection error")
+    error.__context__ = httpcore.ConnectError()
+    mock_tools.httpx.stream.side_effect = [error]
+
+    # Download the file
+    with pytest.raises(
+        NetworkFailure,
+        match=(
+            r"a connection to the server could not be established.\n\n"
+            r"The reported cause of the problem "
+        ),
+    ):
+        mock_tools.file.download(
+            url="https://example.com/something.zip",
+            download_path=mock_tools.base_path,
+        )
+
+    # httpx.stream has been invoked, but nothing else.
+    mock_tools.httpx.stream.assert_called_with(
+        "GET",
+        "https://example.com/something.zip",
+        follow_redirects=True,
+        verify=mock_tools.file.ssl_context,
+    )
+
+    # The file doesn't exist as a result of the download failure
+    assert not (mock_tools.base_path / "something.zip").exists()
+
+    # Temporary file was not created, moved, or deleted
+    mock_tools.shutil.move.assert_not_called()
+    mock_tools.os.chmod.assert_not_called()
+    mock_tools.os.remove.assert_not_called()
+
+
+def test_unknown_httpx_connectionerror(mock_tools):
+    """NetworkFailure is raised if an unknown httpx connection error occurs."""
+    # Mock a connection error at the level of httpx
+    error = httpx.ConnectError("connection error")
+    mock_tools.httpx.stream.side_effect = [error]
+
+    # Download the file
+    with pytest.raises(
+        NetworkFailure,
+        match=(
+            r"a connection to the server could not be established.\n\n"
+            r"The reported cause of the problem "
+        ),
+    ):
+        mock_tools.file.download(
+            url="https://example.com/something.zip",
+            download_path=mock_tools.base_path,
+        )
+
+    # httpx.stream has been invoked, but nothing else.
+    mock_tools.httpx.stream.assert_called_with(
+        "GET",
+        "https://example.com/something.zip",
+        follow_redirects=True,
+        verify=mock_tools.file.ssl_context,
     )
 
     # The file doesn't exist as a result of the download failure
