@@ -7,7 +7,14 @@ from briefcase.integrations.base import ToolCache
 from briefcase.integrations.file import File
 from briefcase.integrations.subprocess import Subprocess
 
-WIX_DOWNLOAD_URL = "https://github.com/wixtoolset/wix3/releases/download/wix3141rtm/wix314-binaries.zip"
+WIX_DOWNLOAD_URL = (
+    "https://github.com/wixtoolset/wix/releases/download/v5.0.2/wix-cli-x64.msi"
+)
+WIX_EXE_PATH = "PFiles64/WiX Toolset v5.0/bin/wix.exe"
+WIX_UI_PATH = (
+    "CFiles64/WixToolset/extensions/WixToolset.UI.wixext/5.0.2/wixext5/"
+    "WixToolset.UI.wixext.dll"
+)
 
 
 @pytest.fixture
@@ -20,3 +27,8 @@ def mock_tools(tmp_path, mock_tools) -> ToolCache:
     mock_tools.file.download = MagicMock(spec_set=File.download)
 
     return mock_tools
+
+
+@pytest.fixture
+def wix_path(tmp_path):
+    return tmp_path / "tools/wix"
