@@ -1,13 +1,12 @@
 import pytest
 
-from briefcase.console import Console
 from briefcase.platforms.iOS.xcode import iOSXcodePackageCommand
 
 
 @pytest.fixture
-def package_command(tmp_path, first_app_config):
+def package_command(dummy_console, tmp_path, first_app_config):
     command = iOSXcodePackageCommand(
-        console=Console(),
+        console=dummy_console,
         base_path=tmp_path / "base_path",
         data_path=tmp_path / "briefcase",
     )
