@@ -4,7 +4,6 @@ from unittest import mock
 
 import pytest
 
-from briefcase.console import Console
 from briefcase.exceptions import BriefcaseCommandError
 from briefcase.integrations.subprocess import Subprocess
 from briefcase.integrations.xcode import DeviceState
@@ -13,9 +12,9 @@ from briefcase.platforms.macOS import macOS_log_clean_filter
 
 
 @pytest.fixture
-def run_command(tmp_path):
+def run_command(dummy_console, tmp_path):
     command = iOSXcodeRunCommand(
-        console=Console(),
+        console=dummy_console,
         base_path=tmp_path / "base_path",
         data_path=tmp_path / "briefcase",
     )
@@ -72,7 +71,7 @@ def test_run_multiple_devices_input_disabled(run_command, first_app_config):
         BriefcaseCommandError,
         match=r"Input has been disabled; can't select a device to target.",
     ):
-        run_command.run_app(first_app_config, test_mode=False, passthrough=[])
+        run_command.run_app(first_app_config, passthrough=[])
 
 
 @pytest.mark.usefixtures("sleep_zero")
@@ -106,7 +105,7 @@ def test_run_app_simulator_booted(run_command, first_app_config, tmp_path):
     ]
 
     # Run the app
-    run_command.run_app(first_app_config, test_mode=False, passthrough=[])
+    run_command.run_app(first_app_config, passthrough=[])
 
     # The correct sequence of commands was issued.
     run_command.tools.subprocess.run.assert_has_calls(
@@ -191,7 +190,6 @@ def test_run_app_simulator_booted(run_command, first_app_config, tmp_path):
     run_command._stream_app_logs.assert_called_with(
         first_app_config,
         popen=log_stream_process,
-        test_mode=False,
         clean_filter=macOS_log_clean_filter,
         clean_output=True,
         stop_func=mock.ANY,
@@ -238,7 +236,7 @@ def test_run_app_simulator_booted_underscore(
     ]
 
     # Run the app
-    run_command.run_app(underscore_app_config, test_mode=False, passthrough=[])
+    run_command.run_app(underscore_app_config, passthrough=[])
 
     # slept 4 times for uninstall/install and 1 time for log stream start
     assert time.sleep.call_count == 4 + 1
@@ -323,7 +321,6 @@ def test_run_app_simulator_booted_underscore(
     run_command._stream_app_logs.assert_called_with(
         underscore_app_config,
         popen=log_stream_process,
-        test_mode=False,
         clean_filter=macOS_log_clean_filter,
         clean_output=True,
         stop_func=mock.ANY,
@@ -364,7 +361,6 @@ def test_run_app_with_passthrough(run_command, first_app_config, tmp_path):
     # Run the app with passthrough args.
     run_command.run_app(
         first_app_config,
-        test_mode=False,
         passthrough=["foo", "--bar"],
     )
 
@@ -453,7 +449,6 @@ def test_run_app_with_passthrough(run_command, first_app_config, tmp_path):
     run_command._stream_app_logs.assert_called_with(
         first_app_config,
         popen=log_stream_process,
-        test_mode=False,
         clean_filter=macOS_log_clean_filter,
         clean_output=True,
         stop_func=mock.ANY,
@@ -498,7 +493,7 @@ def test_run_app_simulator_shut_down(
     ]
 
     # Run the app
-    run_command.run_app(first_app_config, test_mode=False, passthrough=[])
+    run_command.run_app(first_app_config, passthrough=[])
 
     # slept 4 times for uninstall/install and 1 time for log stream start
     assert time.sleep.call_count == 4 + 1
@@ -589,7 +584,6 @@ def test_run_app_simulator_shut_down(
     run_command._stream_app_logs.assert_called_with(
         first_app_config,
         popen=log_stream_process,
-        test_mode=False,
         clean_filter=macOS_log_clean_filter,
         clean_output=True,
         stop_func=mock.ANY,
@@ -640,7 +634,7 @@ def test_run_app_simulator_shutting_down(run_command, first_app_config, tmp_path
     ]
 
     # Run the app
-    run_command.run_app(first_app_config, test_mode=False, passthrough=[])
+    run_command.run_app(first_app_config, passthrough=[])
 
     # We should have slept 4 times for shutting down and 4 time for uninstall/install
     assert time.sleep.call_count == 4 + 4
@@ -731,7 +725,6 @@ def test_run_app_simulator_shutting_down(run_command, first_app_config, tmp_path
     run_command._stream_app_logs.assert_called_with(
         first_app_config,
         popen=log_stream_process,
-        test_mode=False,
         clean_filter=macOS_log_clean_filter,
         clean_output=True,
         stop_func=mock.ANY,
@@ -757,7 +750,7 @@ def test_run_app_simulator_boot_failure(run_command, first_app_config):
 
     # Run the app
     with pytest.raises(BriefcaseCommandError):
-        run_command.run_app(first_app_config, test_mode=False, passthrough=[])
+        run_command.run_app(first_app_config, passthrough=[])
 
     # No sleeps
     assert time.sleep.call_count == 0
@@ -801,7 +794,7 @@ def test_run_app_simulator_open_failure(run_command, first_app_config):
 
     # Run the app
     with pytest.raises(BriefcaseCommandError):
-        run_command.run_app(first_app_config, test_mode=False, passthrough=[])
+        run_command.run_app(first_app_config, passthrough=[])
 
     # No sleeps
     assert time.sleep.call_count == 0
@@ -852,7 +845,7 @@ def test_run_app_simulator_uninstall_failure(run_command, first_app_config):
 
     # Run the app
     with pytest.raises(BriefcaseCommandError):
-        run_command.run_app(first_app_config, test_mode=False, passthrough=[])
+        run_command.run_app(first_app_config, passthrough=[])
 
     # Sleep twice for uninstall failure
     assert time.sleep.call_count == 2
@@ -924,7 +917,7 @@ def test_run_app_simulator_install_failure(run_command, first_app_config, tmp_pa
 
     # Run the app
     with pytest.raises(BriefcaseCommandError):
-        run_command.run_app(first_app_config, test_mode=False, passthrough=[])
+        run_command.run_app(first_app_config, passthrough=[])
 
     # Sleep twice for uninstall and twice for install failure
     assert time.sleep.call_count == 4
@@ -1017,7 +1010,7 @@ def test_run_app_simulator_launch_failure(run_command, first_app_config, tmp_pat
 
     # Run the app
     with pytest.raises(BriefcaseCommandError):
-        run_command.run_app(first_app_config, test_mode=False, passthrough=[])
+        run_command.run_app(first_app_config, passthrough=[])
 
     # Sleep four times for uninstall/install and once for log stream start
     assert time.sleep.call_count == 4 + 1
@@ -1138,7 +1131,7 @@ def test_run_app_simulator_no_pid(run_command, first_app_config, tmp_path):
 
     # Run the app
     with pytest.raises(BriefcaseCommandError):
-        run_command.run_app(first_app_config, test_mode=False, passthrough=[])
+        run_command.run_app(first_app_config, passthrough=[])
 
     # Sleep four times for uninstall/install and once for log stream start
     assert time.sleep.call_count == 4 + 1
@@ -1261,7 +1254,7 @@ def test_run_app_simulator_non_integer_pid(run_command, first_app_config, tmp_pa
 
     # Run the app
     with pytest.raises(BriefcaseCommandError):
-        run_command.run_app(first_app_config, test_mode=False, passthrough=[])
+        run_command.run_app(first_app_config, passthrough=[])
 
     # Sleep four times for uninstall/install and once for log stream start
     assert time.sleep.call_count == 4 + 1
@@ -1355,6 +1348,8 @@ def test_run_app_simulator_non_integer_pid(run_command, first_app_config, tmp_pa
 @pytest.mark.usefixtures("sleep_zero")
 def test_run_app_test_mode(run_command, first_app_config, tmp_path):
     """An iOS App can be started in test mode."""
+    first_app_config.test_mode = True
+
     # A valid target device will be selected.
     run_command.select_target_device = mock.MagicMock(
         return_value=("2D3503A3-6EB9-4B37-9B17-C7EFEF2FA32D", "13.2", "iPhone 11")
@@ -1383,7 +1378,7 @@ def test_run_app_test_mode(run_command, first_app_config, tmp_path):
     ]
 
     # Run the app
-    run_command.run_app(first_app_config, test_mode=True, passthrough=[])
+    run_command.run_app(first_app_config, passthrough=[])
 
     # Sleep four times for uninstall/install and once for log stream start
     assert time.sleep.call_count == 4 + 1
@@ -1454,7 +1449,6 @@ def test_run_app_test_mode(run_command, first_app_config, tmp_path):
     run_command._stream_app_logs.assert_called_with(
         first_app_config,
         popen=log_stream_process,
-        test_mode=True,
         clean_filter=macOS_log_clean_filter,
         clean_output=True,
         stop_func=mock.ANY,
@@ -1465,6 +1459,8 @@ def test_run_app_test_mode(run_command, first_app_config, tmp_path):
 @pytest.mark.usefixtures("sleep_zero")
 def test_run_app_test_mode_with_passthrough(run_command, first_app_config, tmp_path):
     """An iOS App can be started in test mode with passthrough args."""
+    first_app_config.test_mode = True
+
     # A valid target device will be selected.
     run_command.select_target_device = mock.MagicMock(
         return_value=("2D3503A3-6EB9-4B37-9B17-C7EFEF2FA32D", "13.2", "iPhone 11")
@@ -1495,7 +1491,6 @@ def test_run_app_test_mode_with_passthrough(run_command, first_app_config, tmp_p
     # Run the app with args.
     run_command.run_app(
         first_app_config,
-        test_mode=True,
         passthrough=["foo", "--bar"],
     )
 
@@ -1570,7 +1565,6 @@ def test_run_app_test_mode_with_passthrough(run_command, first_app_config, tmp_p
     run_command._stream_app_logs.assert_called_with(
         first_app_config,
         popen=log_stream_process,
-        test_mode=True,
         clean_filter=macOS_log_clean_filter,
         clean_output=True,
         stop_func=mock.ANY,
