@@ -1,15 +1,14 @@
 import pytest
 
-from briefcase.console import Console
 from briefcase.platforms.linux.appimage import LinuxAppImagePackageCommand
 
 from ....utils import create_file
 
 
 @pytest.fixture
-def package_command(tmp_path, first_app_config):
+def package_command(dummy_console, tmp_path, first_app_config):
     command = LinuxAppImagePackageCommand(
-        console=Console(),
+        console=dummy_console,
         base_path=tmp_path / "base_path",
         data_path=tmp_path / "briefcase",
     )
