@@ -4,7 +4,6 @@ from unittest.mock import MagicMock
 
 import pytest
 
-from briefcase.console import Console
 from briefcase.integrations.subprocess import Subprocess
 from briefcase.platforms.linux.flatpak import LinuxFlatpakOpenCommand
 
@@ -12,9 +11,9 @@ from ....utils import create_file
 
 
 @pytest.fixture
-def open_command(tmp_path, first_app_config):
+def open_command(dummy_console, tmp_path, first_app_config):
     command = LinuxFlatpakOpenCommand(
-        console=Console(),
+        console=dummy_console,
         base_path=tmp_path / "base_path",
         data_path=tmp_path / "briefcase",
     )
