@@ -1,15 +1,11 @@
-import sys
 from unittest.mock import MagicMock
 
 import pytest
 
-from briefcase.console import Console
 from briefcase.exceptions import BriefcaseCommandError
 from briefcase.platforms.linux import parse_freedesktop_os_release
 from briefcase.platforms.linux.system import LinuxSystemRunCommand
 
-from ....utils import create_file
-
 
 def test_docker(create_command, first_app_config):
     """An app can be finalized inside docker."""
@@ -53,15 +49,9 @@ def test_nodocker(create_command, first_app_config, tmp_path):
             "ID_LIKE=debian",
         ]
     )
-    if sys.version_info >= (3, 10):
-        # mock platform.freedesktop_os_release()
-        create_command.tools.platform.freedesktop_os_release = MagicMock(
-            return_value=parse_freedesktop_os_release(os_release)
-        )
-    else:
-        # For Pre Python3.10, mock the /etc/release file
-        create_file(tmp_path / "os-release", os_release)
-        create_command.tools.ETC_OS_RELEASE = tmp_path / "os-release"
+    create_command.tools.platform.freedesktop_os_release = MagicMock(
+        return_value=parse_freedesktop_os_release(os_release)
+    )
 
     # Finalize the app config
     create_command.finalize_app_config(first_app_config)
@@ -82,15 +72,9 @@ def test_nodocker_non_freedesktop(create_command, first_app_config, tmp_path):
     create_command.target_image = None
     create_command.target_glibc_version = MagicMock(return_value="2.42")
 
-    if sys.version_info >= (3, 10):
-        # mock platform.freedesktop_os_release()
-        create_command.tools.platform.freedesktop_os_release = MagicMock(
-            side_effect=FileNotFoundError
-        )
-    else:
-        # For Pre Python3.10, mock the /etc/release file
-        # but don't create the file
-        create_command.tools.ETC_OS_RELEASE = tmp_path / "os-release"
+    create_command.tools.platform.freedesktop_os_release = MagicMock(
+        side_effect=FileNotFoundError
+    )
 
     # Finalize the app config
     with pytest.raises(
@@ -496,10 +480,10 @@ def test_properties_no_version(create_command, first_app_config):
     assert first_app_config.python_version_tag == "3"
 
 
-def test_passive_mixin(first_app_config, tmp_path):
+def test_passive_mixin(dummy_console, first_app_config, tmp_path):
     """An app using the PassiveMixin can be finalized."""
     run_command = LinuxSystemRunCommand(
-        console=Console(),
+        console=dummy_console,
         base_path=tmp_path / "base_path",
         data_path=tmp_path / "briefcase",
     )
@@ -515,15 +499,9 @@ def test_passive_mixin(first_app_config, tmp_path):
             "ID_LIKE=debian",
         ]
     )
-    if sys.version_info >= (3, 10):
-        # mock platform.freedesktop_os_release()
-        run_command.tools.platform.freedesktop_os_release = MagicMock(
-            return_value=parse_freedesktop_os_release(os_release)
-        )
-    else:
-        # For Pre Python3.10, mock the /etc/release file
-        create_file(tmp_path / "os-release", os_release)
-        run_command.tools.ETC_OS_RELEASE = tmp_path / "os-release"
+    run_command.tools.platform.freedesktop_os_release = MagicMock(
+        return_value=parse_freedesktop_os_release(os_release)
+    )
 
     # Finalize the app config
     run_command.finalize_app_config(first_app_config)
@@ -536,3 +514,76 @@ def test_passive_mixin(first_app_config, tmp_path):
 
     # For tests of other properties merged in finalization, see
     # test_properties
+
+
+def test_cascading_distribution_properties(create_command, first_app_config):
+    """Properties should be cascading/accumulating, and vendor-level properties should
+    overwrite os-level ones when in a dictionary."""
+    # Run this test as "docker"; however, the things we're testing aren't docker specific.
+    create_command.target_image = "somevendor:surprising"
+    create_command.tools.docker = MagicMock()
+    create_command.target_glibc_version = MagicMock(return_value="2.42")
+
+    # Mock a minimal response from checking /etc/os-release
+    create_command.tools.docker.check_output.return_value = "\n".join(
+        [
+            "ID=somevendor",
+            "VERSION_CODENAME=surprising",
+            "ID_LIKE=debian",
+        ]
+    )
+
+    # Modify the app config with distribution-level properties
+    first_app_config.requires = []
+    first_app_config.permission = {}
+
+    first_app_config.debian = {
+        "requires": ["debian level prop"],
+        "permission": {"prop1": "debian level prop 1", "prop2": "debian level prop 2"},
+    }
+    first_app_config.somevendor = {
+        "requires": ["vendor level prop"],
+        "permission": {"prop1": "vendor level prop 1"},
+    }
+
+    create_command.finalize_app_config(first_app_config)
+
+    # The target's config attributes have been merged into the app
+    # List properties should be accumulated
+    assert first_app_config.requires == ["debian level prop", "vendor level prop"]
+    # Dictionary properties should overwrite higher-level ones and accumulate
+    assert first_app_config.permission == {
+        "prop1": "vendor level prop 1",
+        "prop2": "debian level prop 2",
+    }
+
+
+def test_external_docker(create_command, first_app_config):
+    """An external app cannot be finalized inside Docker."""
+    # Make the app external
+    first_app_config.sources = None
+    first_app_config.external_package_path = "path/to/package"
+
+    # Build the app on a specific target
+    create_command.target_image = "somevendor:surprising"
+    create_command.tools.docker = MagicMock()
+    create_command.target_glibc_version = MagicMock(return_value="2.42")
+
+    # Mock a minimal response from checking /etc/os-release
+    create_command.tools.docker.check_output.return_value = "\n".join(
+        [
+            "ID=somevendor",
+            "VERSION_CODENAME=surprising",
+            "ID_LIKE=debian",
+        ]
+    )
+
+    # Finalize the app config - this will raise an error
+    with pytest.raises(
+        BriefcaseCommandError,
+        match=(
+            r"Briefcase can't currently use Docker to package "
+            r"external apps as Linux system packages."
+        ),
+    ):
+        create_command.finalize_app_config(first_app_config)
