@@ -1,14 +1,13 @@
 import pytest
 
-from briefcase.console import Console
 from briefcase.exceptions import UnsupportedHostError
 from briefcase.platforms.web.static import StaticWebCreateCommand
 
 
 @pytest.fixture
-def create_command(tmp_path):
+def create_command(dummy_console, tmp_path):
     return StaticWebCreateCommand(
-        console=Console(),
+        console=dummy_console,
         base_path=tmp_path / "base_path",
         data_path=tmp_path / "briefcase",
     )
