@@ -5,7 +5,6 @@ from unittest import mock
 
 import pytest
 
-from briefcase.console import Console
 from briefcase.exceptions import BriefcaseCommandError
 from briefcase.platforms.web.static import (
     HTTPHandler,
@@ -23,9 +22,9 @@ class ErrnoError(OSError):
 
 
 @pytest.fixture
-def run_command(tmp_path):
+def run_command(dummy_console, tmp_path):
     command = StaticWebRunCommand(
-        console=Console(),
+        console=dummy_console,
         base_path=tmp_path / "base_path",
         data_path=tmp_path / "briefcase",
     )
@@ -107,7 +106,6 @@ def test_run(monkeypatch, run_command, first_app_built):
     # Run the app
     run_command.run_app(
         first_app_built,
-        test_mode=False,
         passthrough=[],
         host="localhost",
         port=8080,
@@ -172,7 +170,6 @@ def test_run_with_fallback_port(
     # Run the app
     run_command.run_app(
         first_app_built,
-        test_mode=False,
         passthrough=[],
         host="localhost",
         port=8080,
@@ -226,7 +223,6 @@ def test_run_with_args(monkeypatch, run_command, first_app_built):
     # Run the app
     run_command.run_app(
         first_app_built,
-        test_mode=False,
         passthrough=["foo", "--bar"],
         host="localhost",
         port=8080,
@@ -321,7 +317,6 @@ def test_cleanup_server_error(
     with pytest.raises(BriefcaseCommandError, match=message):
         run_command.run_app(
             first_app_built,
-            test_mode=False,
             passthrough=[],
             host=host,
             port=port,
@@ -370,7 +365,6 @@ def test_cleanup_runtime_server_error(monkeypatch, run_command, first_app_built)
     with pytest.raises(ValueError):
         run_command.run_app(
             first_app_built,
-            test_mode=False,
             passthrough=[],
             host="localhost",
             port=8080,
@@ -420,7 +414,6 @@ def test_run_without_browser(monkeypatch, run_command, first_app_built):
     # Run the app
     run_command.run_app(
         first_app_built,
-        test_mode=False,
         passthrough=[],
         host="localhost",
         port=8080,
@@ -471,7 +464,6 @@ def test_run_autoselect_port(monkeypatch, run_command, first_app_built):
     # Run the app on an autoselected port
     run_command.run_app(
         first_app_built,
-        test_mode=False,
         passthrough=[],
         host="localhost",
         port=0,
@@ -561,6 +553,8 @@ def test_log_requests_to_logger(monkeypatch):
 
 def test_test_mode(run_command, first_app_built):
     """Test mode raises an error (at least for now)."""
+    first_app_built.test_mode = True
+
     # Run the app
     with pytest.raises(
         BriefcaseCommandError,
@@ -568,7 +562,6 @@ def test_test_mode(run_command, first_app_built):
     ):
         run_command.run_app(
             first_app_built,
-            test_mode=True,
             passthrough=[],
             host="localhost",
             port=8080,
