@@ -4,15 +4,14 @@ from unittest.mock import MagicMock
 
 import pytest
 
-from briefcase.console import Console
 from briefcase.integrations.subprocess import Subprocess
 from briefcase.platforms.windows.app import WindowsAppOpenCommand
 
 
 @pytest.fixture
-def open_command(tmp_path, first_app_config):
+def open_command(dummy_console, tmp_path, first_app_config):
     command = WindowsAppOpenCommand(
-        console=Console(),
+        console=dummy_console,
         base_path=tmp_path / "base_path",
         data_path=tmp_path / "briefcase",
     )
